%%% File    : test.erl
%%% Author  :  <tony@orre.bluetail.com>
%%% Description : Howto handle widget created by application
%%%               but not child (or grandchild) to any toplevel widget
%%% Created : 21 Feb 2001 by  <tony@orre.bluetail.com>

-module(button_swap).

-compile(export_all).

%% example-start base base.c

-include("../include/gtk.hrl").

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).


create_buttons(Window) ->
    Bs = lists:map(
	   fun(String) ->
		   B = gtk:button_new_with_label(String),
		   gtk:signal_connect(B, 'clicked',
				      fun(_,_) ->
					      io:format("CLICKED ~s\n",
							[String])
				      end, []),
		   B
	   end,
	   [ "Button1", "Button2", "Button3", "Button4" ]),
    put(buttons, Bs),
    Bs.


%% Make sure the reference is at least 1
next_button() ->
    [B|Bs] = get(buttons),
    put(buttons, Bs ++ [B]),
    B.

%% unref all buttons not bound to any widget.
terminate(Bs) ->
    lists:foreach(
      fun(Bn) ->
	      R = gtk:widget_unref(Bn)
      end, Bs),
    gtk:main_quit().


main( ) ->
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    gtk:container_set_border_width (Window, 10),
    gtk:window_set_title(Window, "Button Swap"),

    %% ugly will put buttons in dictionary
    Bs = create_buttons(Window),  

    %% It's a good idea to do this for all windows.
    %%gtk:signal_connect (Window, 'destroy',
    %% fun(W, _) -> gtk:main_quit() end, []),

    gtk:signal_connect (Window, 'delete_event',
			fun(W,_,_) ->
				terminate(Bs)
			end, []),

    Box = gtk:hbox_new(false, 0),
    gtk:container_add(Window, Box),
    gtk:widget_show(Box),

    gtk:container_set_border_width(Box, 2),
    B = next_button(),
    gtk:box_pack_start(Box, B, false, false, 5),

    gtk:widget_show(B),
    
    Next = gtk:button_new_with_label("Next"),
    gtk:box_pack_start(Box, Next, false, false, 5),    
    gtk:signal_connect(Next, 'clicked', 
		       fun(W,D) ->
			       [C|_] = gtk:container_children(Box),
			       gtk:widget_ref(C),
			       gtk:container_remove(Box, C),

			       N = next_button(),
			       gtk:box_pack_start(Box, N, false, false, 5),
			       gtk:box_reorder_child(Box, N, 0),
			       gtk:widget_show(N)
		       end, []),
    gtk:widget_show(Next),    
    
    Close = gtk:button_new_with_label("Close"),
    gtk:box_pack_start(Box, Close, false, false, 5),
    gtk:signal_connect (Close, 'clicked',
			fun(_,_) -> 
				terminate(Bs)
			end, []),
    gtk:widget_show(Close),


    gtk:widget_show  (Window),

    gtk:main ().

%% example-end 



