%%% File    : buttons.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Description : buttons example
%%% Created : 28 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(buttons).

-compile(export_all).

-include("../include/gdk.hrl").

example_file(File) ->
    filename:join([code:lib_dir(erlgtk), "examples", File]).

xpm_label_box(Parent, Xpm_filename, Label_text) ->
    Box1 = gtk:hbox_new (false, 0),
    gtk:container_set_border_width(Box1, 2),
    Style = gtk:widget_get_style(Parent),
    GdkWindow = gtk:widget_get_window(Parent),
    Color = gtk:style_get_bg(Style, 'GTK_STATE_NORMAL'),
    {Pixmap,Mask} = gdk:pixmap_create_from_xpm(GdkWindow, Color, Xpm_filename),
    Pixmapwid = gtk:pixmap_new (Pixmap, Mask),
    Label = gtk:label_new (Label_text),
    gtk:box_pack_start (Box1, Pixmapwid, false, false, 3),
    gtk:box_pack_start (Box1, Label, false, false, 3),
    gtk:widget_show(Pixmapwid),
    gtk:widget_show(Label),
    Box1.

callback(Widget, Data) ->
    io:format("Hello again - ~s was pressed\n", [Data]).

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    %% Create a new window
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),

    gtk:window_set_title(Window, "Pixmap'd Buttons!"),

    %% It's a good idea to do this for all windows.
    gtk:signal_connect (Window, 'destroy',
			fun(W, _) -> gtk:main_quit() end, []),

    gtk:signal_connect (Window, 'delete_event',
			fun(W,_,_) -> gtk:main_quit() end, []),

    %% Sets the border width of the window.
    gtk:container_set_border_width (Window, 10),
    gtk:widget_realize(Window),

    %% Create a new button */
    Button = gtk:button_new (),

    %% Connect the "clicked" signal of the button to our callback */
    gtk:signal_connect (Button, 'clicked', fun callback/2, "cool button"),

    %% This calls our box creating function 
    Box1 = xpm_label_box(Window,  example_file("info.xpm"), "cool button"),

    %% Pack and show all our widgets 
    gtk:widget_show(Box1),

    gtk:container_add (Button, Box1),

    gtk:widget_show(Button),

    gtk:container_add (Window, Button),

    gtk:widget_show (Window),

    %% Rest in gtk_main and wait for the fun to begin!
    gtk:main(),
    ok.


%% example-end 


