%%% File    : draw.erl
%%% Author  :  <tony@orre.bluetail.com>
%%% Purpose : drawing example
%%% Created : 18 Dec 2000 by  <tony@orre.bluetail.com>

-module(draw).
-author('tony@orre.bluetail.com').

-compile(export_all).

-include("../include/gtk.hrl").
-include("../include/gdk.hrl").


run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

%% -dictionary pixmap


create_pixmap(Widget, Width, Height) ->
    GdkWindow  = gtk:widget_get_window(Widget),
    case get(pixmap) of
	undefined -> ok;
	Pixmap0 -> gdk:pixmap_unref(Pixmap0)
    end,
    Pixmap = gdk:pixmap_new(GdkWindow, Width, Height, -1),
    put(pixmap, Pixmap),
    %% io:format("New pixmap = ~p (~w, ~w)\n", [Pixmap, Width, Height]),
    Pixmap.


configure_event(Widget, Event, _) ->
    io:format("CONFIGURE: ~p\n", [Event]),
    case get(pixmap) of
	undefined -> ok;
	Pixmap0 -> gdk:pixmap_unref(Pixmap0)
    end,
    Allocation = gtk:widget_get_allocation(Widget),
    GdkWindow  = gtk:widget_get_window(Widget),
    Pixmap = gdk:pixmap_new(GdkWindow,
			    Allocation#gtk_allocation.width,
			    Allocation#gtk_allocation.height,
			    -1),
    put(pixmap, Pixmap),
    Style    = gtk:widget_get_style(Widget),
    White_gc = gtk:style_get_white_gc(Style),
    gdk:draw_rectangle(Pixmap, White_gc, true,
		       0, 0,
		       Allocation#gtk_allocation.width,
		       Allocation#gtk_allocation.height),
    true.


expose_event(Widget, Event, _) ->
    %% io:format("EXPOSE: ~p\n", [Event]),
    Area = Event#gdk_event_expose.area,
    GdkWindow  = gtk:widget_get_window(Widget),
    Style = gtk:widget_get_style(Widget),
    State = ?GTK_WIDGET_STATE(Widget),
    Gc = gtk:style_get_fg_gc(Style, State),
    gdk:draw_pixmap(GdkWindow, Gc,
		    get(pixmap),
		    Area#gdk_rectangle.x, Area#gdk_rectangle.y,
		    Area#gdk_rectangle.x, Area#gdk_rectangle.y,
		    Area#gdk_rectangle.width,
		    Area#gdk_rectangle.height),
    false.


draw_brush(Widget, X, Y) ->
    UpdateRect =
	#gdk_rectangle { x = trunc(X - 5),
			 y = trunc(Y - 5),
			 width = 10,
			 height = 10},
    gdk:draw_rectangle(get(pixmap),
		       gtk:style_get_black_gc(gtk:widget_get_style(Widget)),
		       true,
		       UpdateRect#gdk_rectangle.x,
		       UpdateRect#gdk_rectangle.y,
		       UpdateRect#gdk_rectangle.width,
		       UpdateRect#gdk_rectangle.height),
    gtk:widget_draw(Widget, UpdateRect).



button_press_event(Widget, Event, _) ->
%%    io:format("BUTTON PRESS: ~p\n", [Event]),
    if Event#gdk_event_button.button == 1 ->
	    case get(pixmap) of
		undefined -> ok;
		_ ->
		    draw_brush (Widget, 
				Event#gdk_event_button.x,
				Event#gdk_event_button.y)
	    end;
       true ->
	    ok
    end,
    true.


motion_notify_event(Widget, Event, _) ->
%%    io:format("MOTION: ~p\n", [Event]),
%%  if Event#gdk_event_motion.is_hint == true ->
%%	  gdk_window_get_pointer (event->window, &x, &y, &state);
    X = Event#gdk_event_motion.x,
    Y = Event#gdk_event_motion.y,
    State = Event#gdk_event_motion.state,
    Pixmap = get(pixmap),
    if State band ?GDK_BUTTON1_MASK =/= 0,
       Pixmap =/= undefined ->
	    draw_brush (Widget, X, Y);
       true ->
	    ok
    end,
    true.


quit () ->
    gtk:main_quit().


main() ->
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    gtk:widget_set_name (Window, "Test Input"),
    Vbox = gtk:vbox_new (false, 0),
    gtk:container_add (?GTK_CONTAINER (Window), Vbox),
    gtk:widget_show (Vbox),

    gtk:signal_connect (?GTK_OBJECT (Window), 'delete_event',
			fun(_,_,_) -> gtk:main_quit() end, ?NULL),

    %% Create the drawing area 

    Drawing_area = gtk:drawing_area_new (),
    gtk:drawing_area_size (?GTK_DRAWING_AREA (Drawing_area), 200, 200),
    gtk:box_pack_start (?GTK_BOX (Vbox), Drawing_area, true, true, 0),

    gtk:widget_show (Drawing_area),

    %% Signals used to handle backing pixmap 

    gtk:signal_connect (?GTK_OBJECT (Drawing_area), 'expose_event',
			fun expose_event/3, ?NULL),
    gtk:signal_connect (?GTK_OBJECT(Drawing_area), 'configure_event',
			fun configure_event/3, ?NULL),

    %% Event signals 

    gtk:signal_connect (?GTK_OBJECT (Drawing_area), 'motion_notify_event',
			fun motion_notify_event/3, ?NULL),
    gtk:signal_connect (?GTK_OBJECT (Drawing_area), 'button_press_event',
			fun button_press_event/3, ?NULL),

    gtk:widget_set_events (Drawing_area, 
			   ?GDK_EXPOSURE_MASK
			   bor ?GDK_LEAVE_NOTIFY_MASK
			   bor ?GDK_BUTTON_PRESS_MASK
			   bor ?GDK_POINTER_MOTION_MASK),
			%%   bor ?GDK_POINTER_MOTION_HINT_MASK),

    %% .. And a quit button 
    Button = gtk:button_new_with_label ("Quit"),
    gtk:box_pack_start (?GTK_BOX (Vbox), Button, false, false, 0),

    gtk:signal_connect(?GTK_OBJECT (Button), 'clicked',
		       fun(_,_) ->
			       gtk:main_quit()
		       end, ?NULL),
    gtk:widget_show (Button),
    gtk:widget_show (Window),
    gtk:main ().


%% example-end 


    
    

    

    


