%%% File    : entry.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : Entry example
%%% Created : 27 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(entry).
-author('tony@bit.hemma.se').

-compile(export_all).
%%-export([Function/Arity, ...]).


%% example-start entry entry.c 

-include("../include/gtk.hrl").

enter_callback( Widget, Entry ) ->
    Entry_text = gtk:entry_get_text(?GTK_ENTRY(Entry)),
    io:format("Entry contents: ~s\n", [Entry_text]).

entry_toggle_editable( Checkbutton, Entry ) ->
    gtk:entry_set_editable(?GTK_ENTRY(Entry),
			   gtk:toggle_button_get_active(
			     ?GTK_TOGGLE_BUTTON(Checkbutton))).

entry_toggle_visibility( Checkbutton, Entry) ->
    gtk:entry_set_visibility(?GTK_ENTRY(Entry),
			     gtk:toggle_button_get_active(
			       ?GTK_TOGGLE_BUTTON(Checkbutton))).

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main( ) ->
    %% create a new window 
    Window = gtk:window_new('GTK_WINDOW_TOPLEVEL'),
    gtk:widget_set_usize( ?GTK_WIDGET (Window), 200, 100),
    gtk:window_set_title(?GTK_WINDOW (Window), "GTK Entry"),
    gtk:signal_connect(?GTK_OBJECT (Window), 'delete_event',
                       fun(_,_) -> gtk:main_quit() end, []),

    Vbox = gtk:vbox_new (false, 0),
    gtk:container_add (?GTK_CONTAINER (Window), Vbox),
    gtk:widget_show (Vbox),

    Entry = gtk:entry_new_with_max_length (50),
    gtk:signal_connect(?GTK_OBJECT(Entry), 'activate',
		       fun enter_callback/2, Entry),

    gtk:entry_set_text (?GTK_ENTRY (Entry), "hello"),
    gtk:entry_append_text (?GTK_ENTRY (Entry), " world"),
    gtk:entry_select_region (?GTK_ENTRY (Entry),
			     0, gtk:entry_get_text_length(?GTK_ENTRY(Entry))),
    gtk:box_pack_start (?GTK_BOX (Vbox), Entry, true, true, 0),
    gtk:widget_show (Entry),

    Hbox = gtk:hbox_new (false, 0),
    gtk:container_add (?GTK_CONTAINER (Vbox), Hbox),
    gtk:widget_show (Hbox),
                                  
    Check1 = gtk:check_button_new_with_label("Editable"),
    gtk:box_pack_start (?GTK_BOX (Hbox), Check1, true, true, 0),
    gtk:signal_connect (?GTK_OBJECT(Check1), 'toggled',
			fun entry_toggle_editable/2, Entry),
    gtk:toggle_button_set_active(?GTK_TOGGLE_BUTTON(Check1), true),
    gtk:widget_show (Check1),
    
    Check2 = gtk:check_button_new_with_label("Visible"),
    gtk:box_pack_start (?GTK_BOX (Hbox), Check2, true, true, 0),
    gtk:signal_connect (?GTK_OBJECT(Check2), 'toggled',
			fun entry_toggle_visibility/2, Entry),
    gtk:toggle_button_set_active(?GTK_TOGGLE_BUTTON(Check2), true),
    gtk:widget_show (Check2),
                                   
    Button = gtk:button_new_with_label ("Close"),
    gtk:signal_connect(?GTK_OBJECT (Button), 'clicked',
		       fun(_, _) -> gtk:main_quit() end,
		       Window),
    gtk:box_pack_start (?GTK_BOX (Vbox), Button, true, true, 0),
    ?GTK_WIDGET_SET_FLAGS(Button, ?GTK_CAN_DEFAULT),
    gtk:widget_grab_default(Button),
    gtk:widget_show(Button),
    gtk:widget_show(Window),
    gtk:main().

%% example-end 
