%%% File    : ip_entry.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Description : ip entry 
%%% Created : 18 Jan 2001 by Tony Rogvall <tony@bit.hemma.se>

-module(ip_entry).

-export([new/0, new_with_ip/1, set_ip/2, get_ip/1]).
-compile(export_all).

-include("../include/gdk.hrl").
-include("../include/gtk.hrl").

new_with_ip({A,B,C,D}) ->
    new(A,B,C,D).

new() ->
    new(-1,-1,-1,-1).

new(A,B,C,D) ->
    IPentry = gtk:hbox_new(false, 2),
    E4 = ip_entry(D, ?GTK_NULL),
    E3 = ip_entry(C, E4),
    E2 = ip_entry(B, E3),
    E1 = ip_entry(A, E2),
    gtk:box_pack_start (?GTK_BOX(IPentry), E1, false, false, 1),
    gtk:box_pack_start (?GTK_BOX(IPentry), E2, false, false, 1),
    gtk:box_pack_start (?GTK_BOX(IPentry), E3, false, false, 1),
    gtk:box_pack_start (?GTK_BOX(IPentry), E4, false, false, 1),
    {W0,H0} = get_string_box("000"),
    %% inset is +1 width -=2 (xthickness + INNER_BORDER=2)*2
    %% default xthickness = 2
    W = W0 + 8,
    %% ???
    H = H0 + 12,
    gtk:widget_set_usize (?GTK_WIDGET(E1), W, H),
    gtk:widget_set_usize (?GTK_WIDGET(E2), W, H),
    gtk:widget_set_usize (?GTK_WIDGET(E3), W, H),
    gtk:widget_set_usize (?GTK_WIDGET(E4), W, H),
    gtk:widget_show(E1),
    gtk:widget_show(E2),
    gtk:widget_show(E3),
    gtk:widget_show(E4),
    gtk:object_set_data(IPentry, "ip-addr", {E1,E2,E3,E4}),
    IPentry.

set_ip(IPEntry, {A,B,C,D}) ->
    case gtk:object_get_data(IPEntry, "ip-addr") of
	{E1,E2,E3,E4} ->
	    gtk:entry_set_text(E1, to_int3(A)),
	    gtk:entry_set_text(E2, to_int3(B)),
	    gtk:entry_set_text(E3, to_int3(C)),
	    gtk:entry_set_text(E4, to_int3(D)),
	    true;
	_ ->
	    false
    end.


get_ip(IPEntry) ->
    case gtk:object_get_data(IPEntry, "ip-addr") of
	{E1,E2,E3,E4} ->
	    AS = gtk:entry_get_text(E1),
	    BS = gtk:entry_get_text(E2),
	    CS = gtk:entry_get_text(E3),
	    DS = gtk:entry_get_text(E4),
	    inet_parse:address(AS ++ "." ++ BS ++ "." ++ CS ++ "." ++ DS);
	_ ->
	    {error,einval}
    end.

%% utils and callbacks

%% Size of a string given font
get_string_box(Font, String) ->
    {     gdk:string_width(Font,String),
	  gdk:string_height(Font,String)  }.

get_string_box(String) ->
    L = gtk:label_new(""),
    gtk:widget_ensure_style(L),
    S = gtk:widget_get_style(L),
    Box = get_string_box(gtk:style_get_font(S), String),
    gtk:widget_destroy(L),
    Box.


to_int3(X) when X >= 0 ->
    case integer_to_list(X) of
	[C1] -> [$0,$0,C1];
	[C2,C1] -> [$0,C2,C1];
	[C3,C2,C1] -> [C3,C2,C1];
	_ -> [$?,$?,$?]
    end;
to_int3(X) ->
    [$?,$?,$?].

ip_entry(N, Next) ->
    E = gtk:entry_new_with_max_length(3),
    gtk:object_set_data(E, "next", Next),
    if N >= 0 ->
	    gtk:entry_set_text(E, to_int3(N));
       true ->
	    ok
    end,
    %% gtk:widget_add_events(E, ?GDK_ENTER_NOTIFY_MASK),
    gtk:signal_connect(E, insert_text, 
		       fun ip_text/5, []),
    gtk:signal_connect(E, focus_in_event, 
		       fun ip_focus/3, []),
    E.

ip_focus(E, Ev, _) ->
    gtk:entry_select_region(E, 0, -1),
    false.
    
ip_text(E, Text, Length, Pos, Data) ->
    Chars = gtk:entry_get_text(E) ++ Text,
    case is_ip(Chars) of
	true ->
	    if length(Chars) == 3 ->
		    case gtk:object_get_data(E, "next") of
			?GTK_NULL ->
			    ok;
			Next ->
			    gtk:widget_grab_focus(Next)
		    end;
	       true -> ok
	    end,
	    Pos;
	false ->
	    gtk:signal_emit_stop_by_name(E, insert_text),
	    Pos
    end.


is_ip(Text) ->
    is_ip(Text, 0).

is_ip([C|Cs], N) when C >= $0, C =< $9 ->
    N1 = N*10 + (C-$0),
    if N1 > 255 -> false;
       true -> is_ip(Cs,N1)
    end;
is_ip([], N) -> true;
is_ip(_, N) ->  false.
    


