%%% File    : label.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : label example
%%% Created : 29 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(label).
-author('tony@bit.hemma.se').

-compile(export_all).

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    gtk:signal_connect (Window, 'destroy',
			fun(_,_) -> gtk:main_quit() end, []),
    gtk:window_set_title (Window, "Label"),
    Hbox = gtk:hbox_new (false, 5),
    Vbox1 = gtk:vbox_new (false, 5),
    gtk:container_add (Window, Hbox),
    gtk:box_pack_start (Hbox, Vbox1, false, false, 0),
    gtk:container_set_border_width (Window, 5),
  
    Frame1 = gtk:frame_new ("Normal Label"),
    Label1 = gtk:label_new ("This is a Normal label"),
    gtk:container_add (Frame1, Label1),
    gtk:box_pack_start (Vbox1, Frame1, false, false, 0),
  
    Frame2 = gtk:frame_new ("Multi-line Label"),
    Label2 = gtk:label_new ("This is a Multi-line label.\nSecond line\n"
			   "Third line"),
    gtk:container_add (Frame2, Label2),
    gtk:box_pack_start (Vbox1, Frame2, false, false, 0),
  
    Frame3 = gtk:frame_new ("Left Justified Label"),
    Label3 = gtk:label_new ("This is a Left-Justified\n"
			   "Multi-line label.\nThird      line"),
    gtk:label_set_justify (Label3, 'GTK_JUSTIFY_LEFT'),
    gtk:container_add (Frame3, Label3),
    gtk:box_pack_start (Vbox1, Frame3, false, false, 0),
  
    Frame4 = gtk:frame_new ("Right Justified Label"),
    Label4 = gtk:label_new ("This is a Right-Justified\nMulti-line label.\n"
			   "Fourth line, (j/k)"),
    gtk:label_set_justify (Label4, 'GTK_JUSTIFY_RIGHT'),
    gtk:container_add (Frame4, Label4),
    gtk:box_pack_start (Vbox1, Frame4, false, false, 0),

    Vbox2 = gtk:vbox_new (false, 5),
    gtk:box_pack_start (Hbox, Vbox2, false, false, 0),
    Frame5 = gtk:frame_new ("Line wrapped label"),
    Label5 = gtk:label_new ("This is an example of a line-wrapped label.  It "
			   "should not be taking up the entire             "
			   %%  big space to test spacing 
			   "width allocated to it, but automatically "
			   "wraps the words to fit.  "
			   "The time has come, for all good men, to come to "
			   "the aid of their party.  "
			   "The sixth sheik's six sheep's sick.\n"
			   "     It supports multiple paragraphs correctly, "
			   "and  correctly   adds "
			   "many          extra  spaces. "),
    gtk:label_set_line_wrap (Label5, true),
    gtk:container_add (Frame5, Label5),
    gtk:container_add (Vbox2, Frame5),
  
    Frame6 = gtk:frame_new ("Filled, wrapped label"),
    Label6 = gtk:label_new (
	      "This is an example of a line-wrapped, filled label.  "
	      "It should be taking "
	      "up the entire              width allocated to it.  "
	      "Here is a sentence to prove "
	      "my point.  Here is another sentence. "
	      "Here comes the sun, do de do de do.\n"
	      "    This is a new paragraph.\n"
	      "    This is another newer, longer, better "
	      "paragraph.  It is coming to an end, "
	      "unfortunately."),
    gtk:label_set_justify (Label6, 'GTK_JUSTIFY_FILL'),
    gtk:label_set_line_wrap (Label6, true),
    gtk:container_add (Frame6, Label6),
    gtk:box_pack_start (Vbox2, Frame6, false, false, 0),
  
    Frame7 = gtk:frame_new ("Underlined label"),
    Label7 = gtk:label_new ("This label is underlined!\n"
			   "This one is underlined in quite a funky fashion"),
    gtk:label_set_justify (Label7, 'GTK_JUSTIFY_LEFT'),
    gtk:label_set_pattern (Label7,
			   "_________________________ _ _________ _ ______     __ _______ ___"),
    gtk:container_add (Frame7, Label7),
    gtk:box_pack_start (Vbox2, Frame7, false, false, 0),
    gtk:widget_show_all(Window),
    gtk:main (),
    0.

%% example-end 


