%%% File    : notebook.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : notebook example
%%% Created : 10 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(notebook).
-author('tony@bit.hemma.se').

-compile(export_all).

%% example-start notebook notebook.c */
-include("../include/gtk.hrl").

%% This function rotates the position of the tabs 
rotate_book(Button, Notebook) ->
    Pos = (gtk:notebook_get_tab_pos(Notebook) + 1) rem 4,
    gtk:notebook_set_tab_pos (Notebook, Pos).

%% Add/Remove the page tabs and the borders 
tabsborder_book(Button, Notebook) ->
    Tval = gtk:notebook_get_show_tabs(Notebook),
    Bval = gtk:notebook_get_show_border(Notebook),
    gtk:notebook_set_show_tabs(Notebook, not Tval),
    gtk:notebook_set_show_border(Notebook, not Bval).


%% Remove a page from the notebook 
remove_book(Button, Notebook) ->
    Page = gtk:notebook_get_current_page(Notebook),
    gtk:notebook_remove_page (Notebook, Page),
    %% Need to refresh the widget -- 
    %% This forces the widget to redraw itself. 
    gtk:widget_draw(?GTK_WIDGET(Notebook), ?NULL).


delete(Widget, Window) ->
    gtk:main_quit(),
    false.

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    
    gtk:signal_connect (?GTK_OBJECT (Window), 'destroy',
			fun(_,_) -> gtk:main_quit() end,
			?NULL),
    
    gtk:container_set_border_width (?GTK_CONTAINER (Window), 10),

    Table = gtk:table_new(3,6,false),
    gtk:container_add (?GTK_CONTAINER (Window), Table),
    
    %% Create a new notebook, place the position of the tabs */
    Notebook = gtk:notebook_new (),
    gtk:notebook_set_tab_pos (?GTK_NOTEBOOK (Notebook), 'GTK_POS_TOP'),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Notebook, 0,6,0,1),
    gtk:widget_show(Notebook),
    
    %% Let's append a bunch of pages to the notebook */
    lists:foreach(
      fun(I) ->
	      Bufferf = io_lib:format("Append Frame ~w", [I+1]),
	      Bufferl = io_lib:format("Page ~w", [I+1]),
	      Frame = gtk:frame_new (lists:flatten(Bufferf)),
	      gtk:container_set_border_width (?GTK_CONTAINER (Frame), 10),
	      gtk:widget_set_usize (Frame, 100, 75),
	      gtk:widget_show (Frame),
	
	      Label1 = gtk:label_new (lists:flatten(Bufferf)),
	      gtk:container_add (?GTK_CONTAINER (Frame), Label1),
	      gtk:widget_show (Label1),
	
	      Label2 = gtk:label_new (lists:flatten(Bufferl)),
	      gtk:notebook_append_page (?GTK_NOTEBOOK (Notebook), 
					Frame, Label2)
      end, lists:seq(0, 4)),
      
    %% Now let's add a page to a specific spot 
    Checkbutton = gtk:check_button_new_with_label ("Check me please!"),
    gtk:widget_set_usize(Checkbutton, 100, 75),
    gtk:widget_show (Checkbutton),
   
    Label = gtk:label_new ("Add page"),
    gtk:notebook_insert_page (?GTK_NOTEBOOK (Notebook), Checkbutton, Label, 2),
    
    %% Now finally let's prepend pages to the notebook 
    lists:foreach(
      fun(I) ->
	      Bufferf = io_lib:format("Prepend Frame ~w", [I+1]),
	      Bufferl = io_lib:format("PPage ~w", [I+1]),

	      Frame = gtk:frame_new (lists:flatten(Bufferf)),
	      gtk:container_set_border_width (?GTK_CONTAINER (Frame), 10),
	      gtk:widget_set_usize (Frame, 100, 75),
	      gtk:widget_show (Frame),
	
	      Label1 = gtk:label_new (lists:flatten(Bufferf)),
	      gtk:container_add (?GTK_CONTAINER (Frame), Label1),
	      gtk:widget_show (Label1),
	
	      Label2 = gtk:label_new (lists:flatten(Bufferl)),
	      gtk:notebook_prepend_page (?GTK_NOTEBOOK(Notebook),
					 Frame, Label2)
      end, lists:seq(0, 4)),
    
    %% Set what page to start at (page 4) 
    gtk:notebook_set_page (?GTK_NOTEBOOK(Notebook), 3),

    %% Create a bunch of buttons */
    Button1 = gtk:button_new_with_label ("close"),
    gtk:signal_connect(?GTK_OBJECT (Button1), 'clicked',
		       fun (Widget, _) ->
			       gtk:widget_destroy(Window),
			       gtk:main_quit()
		       end, ?NULL),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Button1, 0,1,1,2),
    gtk:widget_show(Button1),
    
    Button2 = gtk:button_new_with_label ("next page"),
    gtk:signal_connect(?GTK_OBJECT (Button2), 'clicked',
		       fun(_, N) ->
			       gtk:notebook_next_page(N)
		       end,
		       ?GTK_OBJECT (Notebook)),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Button2, 1,2,1,2),
    gtk:widget_show(Button2),
    
    Button3 = gtk:button_new_with_label ("prev page"),
    gtk:signal_connect (?GTK_OBJECT (Button3), 'clicked',
			fun(_,N) ->
				gtk:notebook_prev_page(N)
			end, ?GTK_OBJECT (Notebook)),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Button3, 2,3,1,2),
    gtk:widget_show(Button3),
    
    Button4 = gtk:button_new_with_label ("tab position"),
    gtk:signal_connect (?GTK_OBJECT (Button4), 'clicked',
                        fun rotate_book/2,
			?GTK_OBJECT(Notebook)),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Button4, 3,4,1,2),
    gtk:widget_show(Button4),
    
    Button5 = gtk:button_new_with_label ("tabs/border on/off"),
    gtk:signal_connect (?GTK_OBJECT (Button5), 'clicked',
                        fun tabsborder_book/2,
                        ?GTK_OBJECT (Notebook)),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Button5, 4,5,1,2),
    gtk:widget_show(Button5),
    
    Button6 = gtk:button_new_with_label ("remove page"),
    gtk:signal_connect (?GTK_OBJECT (Button6), 'clicked',
                        fun remove_book/2,
                        ?GTK_OBJECT(Notebook)),
    gtk:table_attach_defaults(?GTK_TABLE(Table), Button6, 5,6,1,2),
    gtk:widget_show(Button6),
    
    gtk:widget_show(Table),
    gtk:widget_show(Window),

    gtk:main (),
    
    0.

%% example-end 


