%%% File    : packbox.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : derived from packbox.c
%%% Created : 16 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(packbox).
-author('tony@bit.hemma.se').

-export([run/0, run/1, main/1]).


delete_event(Window, Ev, _) ->
    io:format("delete_event: Obj = ~p, Event = ~p\n", [Window, Ev]),
    false.

quit(Button, Window) ->
    io:format("quit called (window=~p)\n", [Window]),
    gtk:quit().


make_box(Homogeneous, Spacing, Expand, Fill, Padding) ->
    Box = gtk:hbox_new(Homogeneous, Spacing),
    Button1 = gtk:button_new_with_label("gtk_box_pack"),
    gtk:box_pack_start(Box, Button1, Expand, Fill, Padding),
    gtk:widget_show(Button1),

    Button2 = gtk:button_new_with_label("(box,"),
    gtk:box_pack_start(Box, Button2, Expand, Fill, Padding),
    gtk:widget_show(Button2),

    Button3 = gtk:button_new_with_label("button,"),
    gtk:box_pack_start(Box, Button3, Expand, Fill, Padding),
    gtk:widget_show(Button3),

    Button4 = 
	if Expand == true ->
		gtk:button_new_with_label("true,");
	   true ->
		gtk:button_new_with_label("false,")
	end,
    gtk:box_pack_start(Box, Button4, Expand, Fill, Padding),
    gtk:widget_show(Button4),

    Button5 = 
	if Fill == true ->
		gtk:button_new_with_label("true,");
	   true ->
		gtk:button_new_with_label("false,")
	end,
    gtk:box_pack_start(Box, Button5, Expand, Fill, Padding),
    gtk:widget_show(Button5),

    Button6 = gtk:button_new_with_label(integer_to_list(Padding)++");"),
    gtk:box_pack_start(Box, Button6, Expand, Fill, Padding),
    gtk:widget_show(Button6),

    Box.

run() ->
    run(1),
    run(2),
    run(3).


run(Which) ->
    gtk:start(),
    spawn_link(?MODULE, main, [Which]).


main(Which) ->
    Window = gtk:window_new('GTK_WINDOW_TOPLEVEL'),

    gtk:signal_connect(Window, 'delete_event', fun delete_event/3, []),
    
    gtk:container_set_border_width(Window, 10),
   
    Box1 = gtk:vbox_new (false, 0),
    
    case Which of
	1 ->
	    Label1 = gtk:label_new ("gtk_hbox_new (false, 0);"),
	    gtk:misc_set_alignment (Label1, 0, 0),
	    gtk:box_pack_start (Box1, Label1, false, false, 0),
	    gtk:widget_show (Label1),

	    Box2 = make_box (false, 0, false, false, 0),
	    gtk:box_pack_start (Box1, Box2, false, false, 0),
	    gtk:widget_show (Box2),

	    Box3 = make_box (false, 0, true, false, 0),
	    gtk:box_pack_start (Box1, Box3, false, false, 0),
	    gtk:widget_show (Box3),
	
	    Box4 = make_box (false, 0, true, true, 0),
	    gtk:box_pack_start (Box1, Box4, false, false, 0),
	    gtk:widget_show (Box4),

	    Separator1 = gtk:hseparator_new(),
	
	    gtk:box_pack_start(Box1, Separator1, false, true, 5),
	    gtk:widget_show(Separator1),
	
	    Label2 = gtk:label_new ("gtk_hbox_new (true, 0);"),
	    gtk:misc_set_alignment (Label2, 0, 0),
	    gtk:box_pack_start (Box1, Label2, false, false, 0),
	    gtk:widget_show(Label2),
	
	    Box5 = make_box (true, 0, true, false, 0),
	    gtk:box_pack_start (Box1, Box5, false, false, 0),
	    gtk:widget_show(Box5),
	
	    Box6 = make_box (true, 0, true, true, 0),
	    gtk:box_pack_start (Box1, Box6, false, false, 0),
	    gtk:widget_show (Box6),
	
	    Separator2 = gtk:hseparator_new(),
	    gtk:box_pack_start (Box1, Separator2, false, true, 5),
	    gtk:widget_show(Separator2);

	2 ->
	    Label1 = gtk:label_new ("gtk_hbox_new (false, 10);"),
	    gtk:misc_set_alignment (Label1, 0, 0),
	    gtk:box_pack_start (Box1, Label1, false, false, 0),
	    gtk:widget_show (Label1),
	
	    Box2 = make_box (false, 10, true, false, 0),
	    gtk:box_pack_start (Box1, Box2, false, false, 0),
	    gtk:widget_show (Box2),
	
	    Box3 = make_box (false, 10, true, true, 0),
	    gtk:box_pack_start (Box1, Box3, false, false, 0),
	    gtk:widget_show (Box3),
	
	    Separator1 = gtk:hseparator_new (),
	    gtk:box_pack_start (Box1, Separator1, false, true, 5),
	    gtk:widget_show (Separator1),
	
	    Label2 = gtk:label_new ("gtk_hbox_new (false, 0),"),
	    gtk:misc_set_alignment (Label2, 0, 0),
	    gtk:box_pack_start (Box1, Label2, false, false, 0),
	    gtk:widget_show (Label2),
	
	    Box4 = make_box (false, 0, true, false, 10),
	    gtk:box_pack_start (Box1, Box4, false, false, 0),
	    gtk:widget_show (Box4),
	
	    Box5 = make_box (false, 0, true, true, 10),
	    gtk:box_pack_start (Box1, Box5, false, false, 0),
	    gtk:widget_show (Box5),
	
	    Separator2 = gtk:hseparator_new (),
	    gtk:box_pack_start (Box1, Separator2, false, true, 5),
	    gtk:widget_show (Separator2);
    
	3 ->
	    Box2 = make_box (false, 0, false, false, 0),
	    Label = gtk:label_new ("end"),
	    gtk:box_pack_end (Box2, Label, false, false, 0),
	    gtk:widget_show (Label),
	
	    gtk:box_pack_start (Box1, Box2, false, false, 0),
	    gtk:widget_show (Box2),
	
	    Separator = gtk:hseparator_new (),
	    gtk:widget_set_usize (Separator, 400, 5),
	    gtk:box_pack_start (Box1, Separator, false, true, 5),
	    gtk:widget_show (Separator)
    end,

    Quitbox = gtk:hbox_new (false, 0),
    Button = gtk:button_new_with_label ("Quit"),
    gtk:signal_connect(Button, 'clicked', fun quit/2, Window),

    gtk:box_pack_start (Quitbox, Button, true, false, 0),
    gtk:box_pack_start (Box1, Quitbox, false, false, 0),
    gtk:container_add (Window, Box1),
    gtk:widget_show (Button),
    gtk:widget_show (Quitbox),
    gtk:widget_show (Box1),
    gtk:widget_show (Window),
    gtk:main().



    
		
	    

    
    
    

