%%% File    : paned.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : paned example
%%% Created : 17 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(paned).
-author('tony@bit.hemma.se').

-compile(export_all).

%% example-start paned paned.c 

-include("../include/gtk.hrl").
   
%% Create the list of "messages" 
create_list() ->
    %%  Create a new scrolled window, with scrollbars only if needed */
    Scrolled_window = gtk:scrolled_window_new (?GTK_NULL, ?GTK_NULL),
    gtk:scrolled_window_set_policy (?GTK_SCROLLED_WINDOW (Scrolled_window),
				    'GTK_POLICY_AUTOMATIC', 
				    'GTK_POLICY_AUTOMATIC'),
   
    %% Create a new list and put it in the scrolled window 
    List = gtk:list_new (),
    gtk:scrolled_window_add_with_viewport (
      ?GTK_SCROLLED_WINDOW (Scrolled_window), List),
    gtk:widget_show (List),
   
    %% Add some messages to the window 
    lists:foreach(
      fun(I) ->
	      Buffer = io_lib:format("Message #~w",[I]),
	      List_item = gtk:list_item_new_with_label (lists:flatten(Buffer)),
	      gtk:container_add (?GTK_CONTAINER(List), List_item),
	      gtk:widget_show (List_item)
      end, lists:seq(0,9)),
    Scrolled_window.
   
%% Add some text to our text widget - this is a callback that is invoked
%% when our window is realized. We could also force our window to be
%% realized with gtk_widget_realize, but it would have to be part of
%% a hierarchy first 

realize_text( Text, Data ) ->
    gtk:text_freeze (?GTK_TEXT (Text)),
    Style = gtk:widget_get_style(Text),
    Black = gtk:style_get_black(Style),
    gtk:text_insert (?GTK_TEXT (Text), ?NULL, Black, ?NULL,
    "From: pathfinder@nasa.gov\n"
    "To: mom@nasa.gov\n"
    "Subject: Made it!\n"
    "\n"
    "We just got in this morning. The weather has been\n"
    "great - clear but cold, and there are lots of fun sights.\n"
    "Sojourner says hi. See you soon.\n"
    " -Path\n", -1),
    gtk:text_thaw (?GTK_TEXT (Text)).

   
%% Create a scrolled text area that displays a "message" 
create_text( ) ->
    %% Create a table to hold the text widget and scrollbars 
    Table = gtk:table_new (2, 2, false),
   
    %% Put a text widget in the upper left hand corner. Note the use of
    %% GTK_SHRINK in the y direction 
    Text = gtk:text_new (?GTK_NULL, ?GTK_NULL),
    gtk:table_attach (?GTK_TABLE (Table), Text, 0, 1, 0, 1,
		      ?GTK_FILL bor ?GTK_EXPAND,
		      ?GTK_FILL bor ?GTK_EXPAND bor ?GTK_SHRINK, 0, 0),
    gtk:widget_show (Text),
   
    %% Put a HScrollbar in the lower left hand corner 
    Hscrollbar = gtk:hscrollbar_new (gtk:text_get_hadj(Text)),
    gtk:table_attach (?GTK_TABLE (Table), Hscrollbar, 0, 1, 1, 2,
		      ?GTK_EXPAND bor ?GTK_FILL, ?GTK_FILL, 0, 0),
    gtk:widget_show (Hscrollbar),
   
    %% And a VScrollbar in the upper right 
    Vscrollbar = gtk:vscrollbar_new (gtk:text_get_vadj(Text)),
    gtk:table_attach (?GTK_TABLE (Table), Vscrollbar, 1, 2, 0, 1,
		      ?GTK_FILL, ?GTK_EXPAND bor ?GTK_FILL bor ?GTK_SHRINK,
		      0, 0),
    gtk:widget_show (Vscrollbar),
  
    %% Add a handler to put a message in the text widget when it is realized 
    gtk:signal_connect (?GTK_OBJECT (Text), 'realize',
			fun realize_text/2, ?NULL),
   
    Table.

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).
   
main( ) ->
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    gtk:window_set_title (?GTK_WINDOW (Window), "Paned Windows"),
    gtk:signal_connect (?GTK_OBJECT (Window), 'destroy',
			fun(_,_) -> gtk:main_quit() end, ?NULL),
    gtk:container_set_border_width (?GTK_CONTAINER (Window), 10),
    gtk:widget_set_usize (?GTK_WIDGET(Window), 450, 400),

    %% create a vpaned widget and add it to our toplevel window */
   
    Vpaned = gtk:vpaned_new (),
    gtk:container_add (?GTK_CONTAINER(Window), Vpaned),
    %% gtk:paned_set_handle_size (?GTK_PANED(Vpaned), 10),
    %% gtk:paned_set_gutter_size (?GTK_PANED(Vpaned), 15),
    gtk:widget_show (Vpaned),
   
    %% Now create the contents of the two halves of the window */
   
    List = create_list (),
    gtk:paned_add1 (?GTK_PANED(Vpaned), List),
    gtk:widget_show (List),
   
    Text = create_text (),
    gtk:paned_add2 (?GTK_PANED(Vpaned), Text),
    gtk:widget_show (Text),
    gtk:widget_show (Window),
    gtk:main ().

%% example-end 
