%%% File    : pixmap.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : pixmap example
%%% Created : 29 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(pixmap).
-author('tony@bit.hemma.se').

-compile(export_all).
-include("../include/gtk.hrl").
-include("../include/gdk.hrl").

%% XPM data of Open-File icon 

xpm_data() ->
 {
	"16 16 3 1\0",
    "       c None\0",
    ".      c #000000000000\0",
    "X      c #FFFFFFFFFFFF\0",
    "                \0",
    "   ......       \0",
    "   .XXX.X.      \0",
    "   .XXX.XX.     \0",
    "   .XXX.XXX.    \0",
    "   .XXX.....    \0",
    "   .XXXXXXX.    \0",
    "   .XXXXXXX.    \0",
    "   .XXXXXXX.    \0",
    "   .XXXXXXX.    \0",
    "   .XXXXXXX.    \0",
    "   .XXXXXXX.    \0",
    "   .XXXXXXX.    \0",
    "   .........    \0",
    "                \0",
    "                \0" }.



%% when invoked (via signal delete_event), terminates the application.
%%
close_application(Widget, Event, Data) ->
    gtk:main_quit().

%% is invoked when the button is clicked.  It just prints a message.
%%
button_clicked(Widget, Data) ->
    io:format( "button clicked\n" ).

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    %% create the main window, and attach delete_event signal to terminating
    %% he application 
    Window = gtk:window_new('GTK_WINDOW_TOPLEVEL'),
    gtk:signal_connect(Window, 'delete_event',
		       fun close_application/3, []),
    gtk:container_set_border_width(Window,  10),
    gtk:widget_show( Window ),

    %% now for the pixmap from gdk 
    %% Style = gtk:widget_get_style( Window ),
    %% Color = gtk:style_get(Style, bg, 'GTK_STATE_NORMAL')
    %%
    GdkWindow = gtk:widget_get_window(Window),
    io:format("gdk window= ~p\n", [GdkWindow]),
    BgColor = #gdk_color { pixel = 0, red = 0, green = 0, blue = 0 },
    {Pixmap,Mask} = gdk:pixmap_create_from_xpm_d(GdkWindow, BgColor,
						 xpm_data()),
    %% a pixmap widget to contain the pixmap 
    Pixmapwid = gtk:pixmap_new( Pixmap, Mask),
    gtk:widget_show( Pixmapwid ),

    %% a button to contain the pixmap widget 
    Button = gtk:button_new(),
    gtk:container_add( Button, Pixmapwid ),
    gtk:container_add( Window, Button ),
    gtk:widget_show( Button ),

    gtk:signal_connect( Button, 'clicked',
                        fun button_clicked/2, []),

    %% show the window */
    gtk:main (),
    0.

%% example-end 


