%%% File    : rangewidgets.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Description : rangewidgets example
%%% Created : 28 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>
-module(rangewidgets).

-compile(export_all).

-include("../include/gtk.hrl").

cb_pos_menu_select( Widget, Pos) ->
    %% Set the value position on both scale widgets 
    Hscale = get(hscale),
    Vscale = get(vscale),
    gtk:scale_set_value_pos (Hscale, Pos),
    gtk:scale_set_value_pos (Vscale, Pos).


cb_update_menu_select(Item, Policy) ->
    %% Set the update policy for both scale widgets
    Hscale = get(hscale),
    Vscale = get(vscale),
    gtk:range_set_update_policy (Hscale, Policy),
    gtk:range_set_update_policy (Vscale, Policy).

cb_digits_scale(Adj, _) ->
    %% Set the number of decimal places to which adj->value is rounded 
    Hscale = get(hscale),
    Vscale = get(vscale),
    Value = gtk:adjustment_get_value(Adj),
    gtk:scale_set_digits (Hscale, Value),
    gtk:scale_set_digits (Vscale, Value).

cb_page_size(Get, Set) ->
    %% Set the page size and page increment size of the sample
    %% adjustment to the value specified by the "Page Size" scale
    Hscale = get(hscale),
    Vscale = get(vscale),
    Value = gtk:adjustment_get_value(Get),
    gtk:adjustment_put_page_size(Set, Value),
    gtk:adjustment_put_page_increment(Set, Value),
    gtk:signal_emit(Set, 'changed').


cb_draw_value(Button, _) ->
    %% Turn the value display on the scale widgets off or on depending
    %%  on the state of the checkbutton 
    Hscale = get(hscale),
    Vscale = get(vscale),
    Active = gtk:toggle_button_get_active(Button),
    gtk:scale_set_draw_value (Hscale, Active),
    gtk:scale_set_draw_value (Vscale, Active).  


%% Convenience functions 

make_menu_item(Name, Callback, Data) ->
    Item = gtk:menu_item_new_with_label(Name),
    gtk:signal_connect (Item, 'activate', Callback, Data),
    gtk:widget_show (Item),
    Item.


scale_set_default_values(Scale) ->
    gtk:range_set_update_policy (Scale, 'GTK_UPDATE_CONTINUOUS'),
    gtk:scale_set_digits(Scale, 1),
    gtk:scale_set_value_pos(Scale, 'GTK_POS_TOP'),
    gtk:scale_set_draw_value (Scale, true).


%% makes the sample window 

create_range_controls() ->
    %% Standard window-creating stuff */
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    gtk:signal_connect (Window, 'destroy',
                        fun(_, _) -> gtk:main_quit() end,
                        []),
    gtk:window_set_title (Window, "range controls"),

    Box1 = gtk:vbox_new (false, 0),
    gtk:container_add (Window, Box1),
    gtk:widget_show (Box1),

    Box21 = gtk:hbox_new (false, 10),
    gtk:container_set_border_width (Box21, 10),
    gtk:box_pack_start (Box1, Box21, true, true, 0),
    gtk:widget_show (Box21),

    %% value, lower, upper, step_increment, page_increment, page_size 
    %% Note that the page_size value only makes a difference for
    %% scrollbar widgets, and the highest value you'll get is actually
    %% (upper - page_size).
    Adj1 = gtk:adjustment_new (0.0, 0.0, 101.0, 0.1, 1.0, 1.0),

    Vscale = gtk:vscale_new (Adj1),
    put(vscale, Vscale), %% Global variable :-(
    scale_set_default_values (Vscale),
    gtk:box_pack_start (Box21, Vscale, true, true, 0),
    gtk:widget_show (Vscale),

    Box3 = gtk:vbox_new (false, 10),
    gtk:box_pack_start (Box21, Box3, true, true, 0),
    gtk:widget_show (Box3),

    %% Reuse the same adjustment 
    Hscale = gtk:hscale_new (Adj1),
    put(hscale, Hscale), %% Global variable :-(
    gtk:widget_set_usize (Hscale, 200, 30),
    scale_set_default_values (Hscale),
    gtk:box_pack_start (Box3, Hscale, true, true, 0),
    gtk:widget_show (Hscale),

    %% Reuse the same adjustment again 
    Scrollbar = gtk:hscrollbar_new (Adj1),
    %% Notice how this causes the scales to always be updated
    %% continuously when the scrollbar is moved 
    gtk:range_set_update_policy (Scrollbar, 'GTK_UPDATE_CONTINUOUS'),
    gtk:box_pack_start (Box3, Scrollbar, true, true, 0),
    gtk:widget_show (Scrollbar),

    Box22 = gtk:hbox_new (false, 10),
    gtk:container_set_border_width (Box22, 10),
    gtk:box_pack_start (Box1, Box22, true, true, 0),
    gtk:widget_show (Box22),

    %% A checkbutton to control whether the value is displayed or not 
    Button1= gtk:check_button_new_with_label("Display value on scale widgets"),
    gtk:toggle_button_set_active (Button1, true),
    gtk:signal_connect (Button1, 'toggled',
                        fun cb_draw_value/2, []),
    gtk:box_pack_start (Box22, Button1, true, true, 0),
    gtk:widget_show (Button1),
  
    Box23 = gtk:hbox_new (false, 10),
    gtk:container_set_border_width (Box23, 10),

    %% An option menu to change the position of the value 
    Label1 = gtk:label_new ("Scale Value Position:"),
    gtk:box_pack_start (Box23, Label1, false, false, 0),
    gtk:widget_show (Label1),
  
    Opt1 = gtk:option_menu_new(),
    Menu1 = gtk:menu_new(),

    Item11 = make_menu_item ("Top",
                           fun cb_pos_menu_select/2,
                           'GTK_POS_TOP'),
    gtk:menu_append (Menu1, Item11),
  
    Item12 = make_menu_item ("Bottom", 
			   fun cb_pos_menu_select/2, 
                           'GTK_POS_BOTTOM'),
    gtk:menu_append (Menu1, Item12),
  
    Item13 = make_menu_item ("Left", 
			   fun cb_pos_menu_select/2,
                           'GTK_POS_LEFT'),
    gtk:menu_append (Menu1, Item13),
  
    Item14 = make_menu_item ("Right", fun cb_pos_menu_select/2,
			   'GTK_POS_RIGHT'),
    gtk:menu_append (Menu1, Item14),
  
    gtk:option_menu_set_menu (Opt1, Menu1),
    gtk:box_pack_start (Box23, Opt1, true, true, 0),
    gtk:widget_show (Opt1),

    gtk:box_pack_start (Box1, Box23, true, true, 0),
    gtk:widget_show (Box23),

    Box24 = gtk:hbox_new (false, 10),
    gtk:container_set_border_width (Box24, 10),

    %% Yet another option menu, this time for the update policy of the
    %% scale widgets 
    Label2 = gtk:label_new ("Scale Update Policy:"),
    gtk:box_pack_start (Box24, Label2, false, false, 0),
    gtk:widget_show (Label2),
  
    Opt2 = gtk:option_menu_new(),
    Menu2 = gtk:menu_new(),
  
    Item21 = make_menu_item ("Continuous",
                           fun cb_update_menu_select/2,
                           'GTK_UPDATE_CONTINUOUS'),
    gtk:menu_append (Menu2, Item21),
  
    Item22 = make_menu_item ("Discontinuous",
                            fun cb_update_menu_select/2,
			   'GTK_UPDATE_DISCONTINUOUS'),
    gtk:menu_append (Menu2, Item22),
  
    Item23 = make_menu_item ("Delayed",
                           fun cb_update_menu_select/2,
                           'GTK_UPDATE_DELAYED'),
    gtk:menu_append (Menu2, Item23),
  
    gtk:option_menu_set_menu (Opt2, Menu2),
    gtk:box_pack_start (Box24, Opt2, true, true, 0),
    gtk:widget_show (Opt2),
  
    gtk:box_pack_start (Box1, Box24, true, true, 0),
    gtk:widget_show (Box24),

    Box25 = gtk:hbox_new (false, 10),
    gtk:container_set_border_width (Box25, 10),
  
    %% An HScale widget for adjusting the number of digits on the
    %% sample scales. 
    Label3 = gtk:label_new ("Scale Digits:"),
    gtk:box_pack_start (Box25, Label3, false, false, 0),
    gtk:widget_show (Label3),

    Adj2 = gtk:adjustment_new (1.0, 0.0, 5.0, 1.0, 1.0, 0.0),
    gtk:signal_connect (Adj2, 'value_changed',
                        fun cb_digits_scale/2, []),
    Scale1 = gtk:hscale_new (Adj2),
    gtk:scale_set_digits (Scale1, 0),
    gtk:box_pack_start (Box25, Scale1, true, true, 0),
    gtk:widget_show (Scale1),

    gtk:box_pack_start (Box1, Box25, true, true, 0),
    gtk:widget_show (Box25),
  
    Box26 = gtk:hbox_new (false, 10),
    gtk:container_set_border_width (Box26, 10),
  
    %% And, one last HScale widget for adjusting the page size of the
    %% scrollbar. 
    Label4 = gtk:label_new ("Scrollbar Page Size:"),
    gtk:box_pack_start (Box26, Label4, false, false, 0),
    gtk:widget_show (Label4),

    Adj3 = gtk:adjustment_new (1.0, 1.0, 101.0, 1.0, 1.0, 0.0),
    gtk:signal_connect (Adj3, 'value_changed',
                        fun cb_page_size/2,
			Adj1),
    Scale2 = gtk:hscale_new (Adj3),
    gtk:scale_set_digits (Scale2, 0),
    gtk:box_pack_start (Box26, Scale2, true, true, 0),
    gtk:widget_show (Scale2),

    gtk:box_pack_start (Box1, Box26, true, true, 0),
    gtk:widget_show (Box26),

    Separator = gtk:hseparator_new (),
    gtk:box_pack_start (Box1, Separator, false, true, 0),
    gtk:widget_show (Separator),

    Box27 = gtk:vbox_new (false, 10),
    gtk:container_set_border_width (Box27, 10),
    gtk:box_pack_start (Box1, Box27, false, true, 0),
    gtk:widget_show (Box27),

    Button2 = gtk:button_new_with_label ("Quit"),
    gtk:signal_connect(Button2, 'clicked',
		       fun(_,_) -> gtk:main_quit() end,
		       []),
    gtk:box_pack_start (Box27, Button2, true, true, 0),
    ?GTK_WIDGET_SET_FLAGS(Button2, ?GTK_CAN_DEFAULT),
    gtk:widget_grab_default (Button2),
    gtk:widget_show (Button2),
    gtk:widget_show (Window).

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    create_range_controls(),
    gtk:main(),
    ok.

%% example-end */
