%%% File    : re_entry.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : Regular expression Entry example
%%% Created : 27 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(re_entry).
-author('tony@bit.hemma.se').

-compile(export_all).
%%-export([Function/Arity, ...]).


%% example-start entry entry.c 

-include("../include//gtk.hrl").


entry_toggle_editable( Checkbutton, Entry ) ->
    gtk:entry_set_editable(?GTK_ENTRY(Entry),
			   gtk:toggle_button_get_active(
			     ?GTK_TOGGLE_BUTTON(Checkbutton))).

entry_toggle_visibility( Checkbutton, Entry) ->
    gtk:entry_set_visibility(?GTK_ENTRY(Entry),
			     gtk:toggle_button_get_active(
			       ?GTK_TOGGLE_BUTTON(Checkbutton))).


re_check(Entry) ->
    String = gtk:entry_get_text(?GTK_ENTRY(Entry)),
    Expr = get(re),
    case regexp:match(String, Expr) of
	nomatch ->
	    io:format("match(~p, ~p) = nomatch\n", [String,Expr]),
	    gtk:widget_set_sensitive(get(button), false);
	Res ->
	    io:format("match(~p, ~p) = ~p\n", [String,Expr,Res]),
	    gtk:widget_set_sensitive(get(button), true)
    end.


insert_before(Entry, Text, Length, Pos, Data) ->
    case lists:member($., Text) of
	true ->
	    gtk:signal_emit_stop_by_name(Entry, "insert_text"),
	    Pos;
	false ->
	    Pos
    end.

insert_after(Entry, Text, Length, Pos, Data) ->
    re_check(Entry),
    Pos.

delete_after(Entry, Start, Stop, _) ->
    re_check(Entry),
    ok.


re_insert_after(RE, Text, Length, Pos, _) ->
    String = gtk:entry_get_text(?GTK_ENTRY(RE)),
    case regexp:parse(String) of
	{ok,Expr} ->
	    put(re, Expr),
	    re_check(get(entry));
	Error ->
	    put(re, epsilon),
	    re_check(get(entry))
    end,
    Pos.

re_delete_after(RE, Start, Stop, _) ->
    String = gtk:entry_get_text(?GTK_ENTRY(RE)),
    case regexp:parse(String) of
	{ok,Expr} ->
	    put(re, Expr),
	    re_check(get(entry));
	Error ->
	    put(re, epsilon),
	    re_check(get(entry))
    end.


run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main( ) ->
    %% create a new window 
    Window = gtk:window_new('GTK_WINDOW_TOPLEVEL'),
    gtk:widget_set_usize( ?GTK_WIDGET (Window), 200, 100),
    gtk:window_set_title(?GTK_WINDOW (Window), "GTK Entry"),
    gtk:signal_connect(?GTK_OBJECT (Window), 'delete_event',
                       fun(_,_,_) -> gtk:main_quit() end, []),

    Vbox = gtk:vbox_new (false, 0),
    gtk:container_add (?GTK_CONTAINER (Window), Vbox),
    gtk:widget_show (Vbox),

    E = gtk:entry_new_with_max_length (50),
    put(entry, E),
    gtk:signal_connect(?GTK_OBJECT(E), 'insert_text',
		       fun insert_before/5, []),
    gtk:signal_connect_after(?GTK_OBJECT(E), 'insert_text',
		       fun insert_after/5, []),
    gtk:signal_connect_after(?GTK_OBJECT(E), 'delete_text',
			     fun delete_after/4, []),
    gtk:box_pack_start (?GTK_BOX (Vbox), E, true, true, 0),


    RE = gtk:entry_new_with_max_length (50),
    {ok,Expr} = regexp:parse(".*"),
    put(re, Expr),
    gtk:entry_set_text (?GTK_ENTRY (RE), ".*"),
    gtk:signal_connect_after(?GTK_OBJECT(RE), 'insert_text',
		       fun re_insert_after/5, []),
    gtk:signal_connect_after(?GTK_OBJECT(RE), 'delete_text',
			     fun re_delete_after/4, []),

    gtk:box_pack_start (?GTK_BOX (Vbox), RE, true, true, 0),


    Hbox = gtk:hbox_new (false, 0),
    gtk:container_add (?GTK_CONTAINER (Vbox), Hbox),
    gtk:widget_show (Hbox),
                                  
    Check1 = gtk:check_button_new_with_label("Editable"),
    gtk:box_pack_start (?GTK_BOX (Hbox), Check1, true, true, 0),
    gtk:signal_connect (?GTK_OBJECT(Check1), 'toggled',
			fun entry_toggle_editable/2, E),
    gtk:toggle_button_set_active(?GTK_TOGGLE_BUTTON(Check1), true),
    gtk:widget_show (Check1),
    
    Check2 = gtk:check_button_new_with_label("Visible"),
    gtk:box_pack_start (?GTK_BOX (Hbox), Check2, true, true, 0),
    gtk:signal_connect (?GTK_OBJECT(Check2), 'toggled',
			fun entry_toggle_visibility/2, E),
    gtk:toggle_button_set_active(?GTK_TOGGLE_BUTTON(Check2), true),
    gtk:widget_show (Check2),
                                   
    Button = gtk:button_new_with_label ("Ok"),
    gtk:signal_connect(?GTK_OBJECT (Button), 'clicked',
		       fun(_, _) -> gtk:main_quit() end,
		       Window),
    put(button, Button),

    gtk:entry_set_text (?GTK_ENTRY (E), "hello"),
    gtk:entry_append_text (?GTK_ENTRY (E), " world"),
    gtk:entry_select_region (?GTK_ENTRY (E),
			     0, gtk:entry_get_text_length(?GTK_ENTRY(E))),

    gtk:widget_show (E),
    gtk:widget_show (RE),

    gtk:box_pack_start (?GTK_BOX (Vbox), Button, true, true, 0),
    ?GTK_WIDGET_SET_FLAGS(Button, ?GTK_CAN_DEFAULT),
    gtk:widget_grab_default(Button),
    gtk:widget_show(Button),
    gtk:widget_show(Window),
    gtk:main().

%% example-end 
