%%% File    : rulers.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : rulers example
%%% Created : 30 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(rulers).
-author('tony@bit.hemma.se').

-compile(export_all).


-include("../include/gdk.hrl").
-include("../include/gtk.hrl").


%% -define(EVENT_METHOD(i, x), GTK_WIDGET_CLASS(GTK_OBJECT(i)->klass)->x).
-define(EVENT_METHOD(I, X), 
	fun(W,E,DW) ->
		gtk:signal_emit(DW, X),
		false
	end).

-define(XSIZE,  600).
-define(YSIZE,  400).

%% This routine gets control when the close button is clicked 
close_application(Widget, Event, Data ) ->
    gtk:main_quit(),
    false.

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    Window = gtk:window_new( 'GTK_WINDOW_TOPLEVEL' ),
    gtk:signal_connect (Window, 'delete_event',
			fun close_application/3, []),
    gtk:container_set_border_width (Window, 10),

    %% Create a table for placing the ruler and the drawing area 
    Table = gtk:table_new(3, 2, false),
    gtk:container_add( Window, Table ),

    Area = gtk:drawing_area_new(),
    gtk:drawing_area_size( Area, ?XSIZE, ?YSIZE ),
    gtk:table_attach( Table, Area, 1, 2, 1, 2,
                      ?GTK_EXPAND bor ?GTK_FILL, ?GTK_FILL, 0, 0 ),
    gtk:widget_set_events(Area, ?GDK_POINTER_MOTION_MASK bor
			        ?GDK_POINTER_MOTION_HINT_MASK ),

    %% The horizontal ruler goes on top. As the mouse moves across the
    %% drawing area, a motion_notify_event is passed to the
    %% appropriate event handler for the ruler. 
    Hrule = gtk:hruler_new(),
    gtk:ruler_set_metric( Hrule, 'GTK_PIXELS' ),
    gtk:ruler_set_range( Hrule, 7, 13, 0, 20 ),

    gtk:signal_connect(Area, 'motion_notify_event',
		       gtk:get_event_method(Hrule, 'motion_notify_event'),
		       Hrule),
    gtk:table_attach( Table, Hrule, 1, 2, 0, 1,
                      ?GTK_EXPAND bor ?GTK_SHRINK bor ?GTK_FILL, 
		      ?GTK_FILL, 0, 0 ),
    
    %% The vertical ruler goes on the left. As the mouse moves across
    %% the drawing area, a motion_notify_event is passed to the
    %% appropriate event handler for the ruler. 
    Vrule = gtk:vruler_new(),
    gtk:ruler_set_metric( Vrule, 'GTK_PIXELS' ),
    gtk:ruler_set_range( Vrule, 0, ?YSIZE, 10, ?YSIZE ),
    gtk:signal_connect(Area, 'motion_notify_event',
		       gtk:get_event_method(Vrule, motion_notify_event),
		       Vrule),
    gtk:table_attach( Table, Vrule, 0, 1, 1, 2,
                      ?GTK_FILL, 
		      ?GTK_EXPAND bor ?GTK_SHRINK bor ?GTK_FILL, 0, 0 ),

    %% Now show everything 
    gtk:widget_show( Area ),
    gtk:widget_show( Hrule ),
    gtk:widget_show( Vrule ),
    gtk:widget_show( Table ),
    gtk:widget_show( Window ),
    gtk:main(),
    0.

%% example-end 


