%%% File    : scrolledwin.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : scrolledwin example
%%% Created : 27 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(scrolledwin).
-author('tony@bit.hemma.se').

-compile(export_all).

%% example-start scrolledwin scrolledwin.c 

-include("../include/gtk.hrl").

destroy( Widget, Data ) ->
    gtk:main_quit().

run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    %% Create a new dialog window for the scrolled window to be packed into.
    Window = gtk:dialog_new (),
    gtk:signal_connect (?GTK_OBJECT (Window), 'destroy',
			fun destroy/2, []),
    gtk:window_set_title (?GTK_WINDOW (Window), "GtkScrolledWindow example"),
    gtk:container_set_border_width (?GTK_CONTAINER (Window), 0),
    gtk:widget_set_usize(Window, 300, 300),
    
    %% create a new scrolled window. 
    Scrolled_window = gtk:scrolled_window_new (?GTK_NULL, ?GTK_NULL),
    
    gtk:container_set_border_width (?GTK_CONTAINER (Scrolled_window), 10),
    
    %% the policy is one of GTK_POLICY AUTOMATIC, or GTK_POLICY_ALWAYS.
    %% GTK_POLICY_AUTOMATIC will automatically decide whether you need
    %% scrollbars, whereas GTK_POLICY_ALWAYS will always leave the scrollbars
    %% there.  The first one is the horizontal scrollbar, the second, 
    %% the vertical. 
    gtk:scrolled_window_set_policy (?GTK_SCROLLED_WINDOW (Scrolled_window),
                                    'GTK_POLICY_AUTOMATIC', 
				    'GTK_POLICY_ALWAYS'),
    %% The dialog window is created with a vbox packed into it.
    gtk:box_pack_start (?GTK_BOX (
			   gtk:dialog_get_vbox(?GTK_DIALOG(Window))),
			Scrolled_window, 
			true, true, 0),
    gtk:widget_show (Scrolled_window),
    
    %% create a table of 10 by 10 squares. 
    Table = gtk:table_new (10, 10, false),
    
    %% set the spacing to 10 on x and 10 on y 
    gtk:table_set_row_spacings (?GTK_TABLE (Table), 10),
    gtk:table_set_col_spacings (?GTK_TABLE (Table), 10),
    
    %% pack the table into the scrolled window 
    gtk:scrolled_window_add_with_viewport (
      ?GTK_SCROLLED_WINDOW (Scrolled_window), Table),
    gtk:widget_show (Table),
    
    %% this simply creates a grid of toggle buttons on the table
    %% to demonstrate the scrolled window. 
    lists:foreach(
      fun(I) ->
	      lists:foreach(
		fun(J) ->
			Buf0 = io_lib:format("button (~w,~w)\n", [I, J]),
			Buffer = lists:flatten(Buf0),
			Button = gtk:toggle_button_new_with_label (Buffer),
			gtk:table_attach_defaults (?GTK_TABLE (Table), Button,
						   I, I+1, J, J+1),
			gtk:widget_show (Button)
		end, lists:seq(0, 9))
      end, lists:seq(0,9)),
    
    %% Add a "close" button to the bottom of the dialog 
    Button = gtk:button_new_with_label ("close"),
    gtk:signal_connect(?GTK_OBJECT (Button), 'clicked',
		       fun(_,W) -> gtk:widget_destroy(W) end,
		       ?GTK_OBJECT(Window)),
    
    %% this makes it so the button is the default. 
    
    ?GTK_WIDGET_SET_FLAGS (Button, ?GTK_CAN_DEFAULT),
    gtk:box_pack_start (?GTK_BOX (
			   gtk:dialog_get_action_area(?GTK_DIALOG (Window))), 
			Button, true, true, 0),
    
    %% This grabs this button to be the default button. Simply hitting
    %% the "Enter" key will cause this button to activate. 
    gtk:widget_grab_default (Button),
    gtk:widget_show (Button),
    
    gtk:widget_show (Window),
    
    gtk:main().

%% example-end 
