%%% File    : statusbar.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : statusbar example
%%% Created : 30 Nov 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(statusbar).
-author('tony@bit.hemma.se').

-compile(export_all).

-include("../include/gtk.hrl").

push_item(Widget, Data) ->
    Status_bar = get(status_bar),
    Count = get(count),
    put(count, Count+1),
    Buff = lists:flatten(io_lib:format("Item ~w", [Count])),
    gtk:statusbar_push(?GTK_STATUSBAR(Status_bar), Data, Buff).

pop_item(Widget, Data) ->
    Status_bar = get(status_bar),
    gtk:statusbar_pop(?GTK_STATUSBAR(Status_bar), Data).


run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main( ) ->
    put(count, 1),
    %% create a new window 
    Window = gtk:window_new('GTK_WINDOW_TOPLEVEL'),
    gtk:widget_set_usize( ?GTK_WIDGET (Window), 200, 100),
    gtk:window_set_title( ?GTK_WINDOW (Window), "GTK Statusbar Example"),
    gtk:signal_connect(?GTK_OBJECT (Window), 'delete_event',
                       fun(_,_,_) -> gtk:main_quit() end, []),
    
    Vbox = gtk:vbox_new(false, 1),
    gtk:container_add(?GTK_CONTAINER(Window), Vbox),
    gtk:widget_show(Vbox),
          
    Status_bar = gtk:statusbar_new(),      
    put(status_bar, Status_bar),
    gtk:box_pack_start (?GTK_BOX (Vbox), Status_bar, true, true, 0),
    gtk:widget_show (Status_bar),

    Context_id = gtk:statusbar_get_context_id(
		   ?GTK_STATUSBAR(Status_bar), "Statusbar example"),

    Button1 = gtk:button_new_with_label("push item"),
    gtk:signal_connect(?GTK_OBJECT(Button1), 'clicked',
		       fun push_item/2,   Context_id),
    gtk:box_pack_start(?GTK_BOX(Vbox), Button1, true, true, 2),
    gtk:widget_show(Button1),              

    Button2 = gtk:button_new_with_label("pop last item"),
    gtk:signal_connect(?GTK_OBJECT(Button2), 'clicked',
		       fun pop_item/2, Context_id ),
    gtk:box_pack_start(?GTK_BOX(Vbox), Button2, true, true, 2),
    gtk:widget_show(Button2),              

    %% always display the window as the last step so it all splashes on
    %% the screen at once. */
    gtk:widget_show(Window),
    gtk:main (),
    0.

%% example-end 


