%%% File    : text.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : text example
%%% Created :  7 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(text).
-author('tony@bit.hemma.se').

-compile(export_all).

%% example-start text text.c 

-include("../include/gtk.hrl").
-include("../include/gdk.hrl").

text_toggle_editable (Checkbutton, Text) ->
    io:format("text_toggle_editable called: ~p ~p\n", [Checkbutton, Text]),
    Active = gtk:toggle_button_get_active(?GTK_TOGGLE_BUTTON(Checkbutton)),
    io:format("text_toggle_editable = ~p\n", [Active]),
    gtk:text_set_editable(?GTK_TEXT(Text), Active).
			  

text_toggle_word_wrap (Checkbutton, Text) ->
    io:format("text_toggle_word_wrap called: ~p ~p\n", [Checkbutton, Text]),
    Active = gtk:toggle_button_get_active(?GTK_TOGGLE_BUTTON(Checkbutton)),
    io:format("text_toggle_word_wrap active = ~p\n", [Active]),
    gtk:text_set_word_wrap(?GTK_TEXT(Text), Active).


close_application(Widget, Data) ->
    gtk:widget_destroy(?GTK_WIDGET(Data)),
    gtk:main_quit().

load_text(File, Text, Font) ->
    case file:open(File, [read]) of
	{ok, Fd} ->
	    Res = load_file(Fd, Text, Font),
	    file:close(Fd),
	    Res;
	Error ->
	    Error
    end.

load_file(Fd, Text, Font) ->
    case file:read(Fd, 1024) of
	{ok, Buffer} ->
	    %% Font,
	    gtk:text_insert (?GTK_TEXT (Text), Font, ?NULL, 
			     ?NULL, Buffer, length(Buffer)),
	    load_file(Fd, Text, Font);
	eof ->
	    ok;
	Error ->
	    Error
    end.


run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main() ->
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),
    gtk:widget_set_usize (Window, 600, 500),
    gtk:window_set_policy (?GTK_WINDOW(Window), true, true, false),  
    gtk:signal_connect (?GTK_OBJECT (Window), 'destroy',
			fun close_application/2,
			Window),
    gtk:window_set_title (?GTK_WINDOW (Window), "Text Widget Example"),
    gtk:container_set_border_width (?GTK_CONTAINER (Window), 0),
  
  
    Box1 = gtk:vbox_new (false, 0),
    gtk:container_add (?GTK_CONTAINER (Window), Box1),
    gtk:widget_show (Box1),
  
  
    Box2 = gtk:vbox_new (false, 10),
    gtk:container_set_border_width (?GTK_CONTAINER (Box2), 10),
    gtk:box_pack_start (?GTK_BOX (Box1), Box2, true, true, 0),
    gtk:widget_show (Box2),
  
    Table = gtk:table_new (2, 2, false),
    gtk:table_set_row_spacing (?GTK_TABLE (Table), 0, 2),
    gtk:table_set_col_spacing (?GTK_TABLE (Table), 0, 2),
    gtk:box_pack_start (?GTK_BOX (Box2), Table, true, true, 0),
    gtk:widget_show (Table),
  
    %% Create the GtkText widget 
    Text = gtk:text_new (?GTK_NULL, ?GTK_NULL),
    gtk:text_set_editable (?GTK_TEXT (Text), true),
    gtk:table_attach (?GTK_TABLE (Table), Text, 0, 1, 0, 1,
		      ?GTK_EXPAND bor ?GTK_SHRINK bor ?GTK_FILL,
		      ?GTK_EXPAND bor ?GTK_SHRINK bor ?GTK_FILL, 0, 0),
    gtk:widget_show (Text),

    %% Add a vertical scrollbar to the GtkText widget
    Vadj = gtk:text_get_vadj(Text),
    Vscrollbar = gtk:vscrollbar_new (Vadj),
    gtk:table_attach (?GTK_TABLE (Table), Vscrollbar, 1, 2, 0, 1,
		      ?GTK_FILL, ?GTK_EXPAND bor ?GTK_SHRINK bor ?GTK_FILL, 0,0),
    gtk:widget_show (Vscrollbar),

    %% Get the system color map and allocate the color red 
    Cmap = gdk:colormap_get_system(),
    Color0 = #gdk_color { red = 16#ffff, green = 0, blue = 0 },
    Color = case gdk:color_alloc(Cmap, Color0) of
		{true, C0} -> C0;
		{false,_} ->
		    io:format("couldn't allocate color ~p\n", [Color0]),
		    Color0
	    end,
    %% Load a fixed font 
    Fixed_font = gdk:font_load("-adobe-helvetica-medium-r-normal-*-*-100-*-*-p-*-iso8859-1"),

    %% Realizing a widget creates a window for it,
    %% ready for us to insert some text */
    gtk:widget_realize (Text),

    %% Freeze the text widget, ready for multiple updates */
    gtk:text_freeze (?GTK_TEXT (Text)),
  
    %% Insert some colored text
    Style = gtk:widget_get_style(Text),
    Black = gtk:style_get_black(Style),
    gtk:text_insert (?GTK_TEXT (Text), ?NULL, Black, ?NULL, "Supports ", -1),
    gtk:text_insert (?GTK_TEXT (Text), ?NULL, Color, ?NULL, "colored ", -1),
    gtk:text_insert (?GTK_TEXT (Text), ?NULL, Black, ?NULL,
		     "text and different ", -1),
    gtk:text_insert (?GTK_TEXT (Text), Fixed_font, Black, ?NULL,
		     "fonts\n\n", -1),

    %% Load the file text.c into the text window 
    load_text("text.erl", Text, Fixed_font),


    %% Thaw the text widget, allowing the updates to become visible */  
    gtk:text_thaw (?GTK_TEXT (Text)),
  
    Hbox = gtk:hbutton_box_new (),
    gtk:box_pack_start (?GTK_BOX (Box2), Hbox, false, false, 0),
    gtk:widget_show (Hbox),

    Check1 = gtk:check_button_new_with_label("Editable"),
    gtk:box_pack_start (?GTK_BOX (Hbox), Check1, false, false, 0),
    gtk:signal_connect (?GTK_OBJECT(Check1), 'toggled',
			fun text_toggle_editable/2, Text),
    gtk:toggle_button_set_active(?GTK_TOGGLE_BUTTON(Check1), true),
    gtk:widget_show (Check1),

    Check2 = gtk:check_button_new_with_label("Wrap Words"),
    gtk:box_pack_start (?GTK_BOX (Hbox), Check2, false, true, 0),
    gtk:signal_connect (?GTK_OBJECT(Check2), 'toggled',
			fun text_toggle_word_wrap/2, Text),
    gtk:toggle_button_set_active(?GTK_TOGGLE_BUTTON(Check2), false),
    gtk:widget_show (Check2),
    
    Separator = gtk:hseparator_new (),
    gtk:box_pack_start (?GTK_BOX (Box1), Separator, false, true, 0),
    gtk:widget_show (Separator),

    Box3 = gtk:vbox_new (false, 10),
    gtk:container_set_border_width (?GTK_CONTAINER (Box3), 10),
    gtk:box_pack_start (?GTK_BOX (Box1), Box3, false, true, 0),
    gtk:widget_show (Box3),
  
    Button = gtk:button_new_with_label ("close"),
    gtk:signal_connect (?GTK_OBJECT (Button), 'clicked',
			fun close_application/2,
			Window),
    gtk:box_pack_start (?GTK_BOX (Box3), Button, true, true, 0),
    ?GTK_WIDGET_SET_FLAGS (Button, ?GTK_CAN_DEFAULT),

    gtk:widget_grab_default (Button),
    gtk:widget_show (Button),

    gtk:widget_show (Window),
    gtk:main (),
    0.

%% example-end */
