%%% File    : tree.erl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Purpose : tree example
%%% Created :  5 Dec 2000 by Tony Rogvall <tony@bit.hemma.se>

-module(tree).
-author('tony@bit.hemma.se').

-compile(export_all).

-include("../include/gtk.hrl").

%% for all the GtkItem:: and GtkTreeItem:: signals */
cb_itemsignal( Item, SigName) ->
    %% It's a Bin, so it has one child, which we know to be a
    %% label, so get that 
    %% label = GTK_LABEL (GTK_BIN (item)->child);
    %% Get the text of the label 
    %% gtk_label_get (label, &name);
    %%  Get the level of the tree which the item is in */
    %% g_print ("%s called for item %s->%p, level %d\n", signame, name,
    %% item, GTK_TREE (item->parent)->level);
    false .

%% Note that this is never called 
cb_unselect_child(Root_tree, Child, Subtree) ->
    io:format("unselect_child called for root tree ~p, subtree ~p, child ~p\n",
	      [Root_tree, Subtree, Child]),
    false.

%% Note that this is called every time the user clicks on an item,
%% whether it is already selected or not. */
cb_select_child (Root_tree, Child, Subtree) ->
    io:format("select_child called for root tree ~p, subtree ~p, child ~p\n",
	      [Root_tree, Subtree, Child]),
    false.


cb_selection_changed(Tree, _) ->
    io:format("selection_change called for tree ~p\n", [Tree]),
    io:format("selected objects are:\n"),
    false.
%     i = GTK_TREE_SELECTION(tree),
%     while (i){
% 	    gchar *name;
% 	    GtkLabel *label;
% 	    GtkWidget *item;
% 	    /* Get a GtkWidget pointer from the list node */
% 	    item = GTK_WIDGET (i->data);
% 	    label = GTK_LABEL (GTK_BIN (item)->child);
% 	    gtk_label_get (label, &name);
% 	    g_print ("\t%s on level %d\n", name, GTK_TREE
% 		     (item->parent)->level);
% 	    i = i->next;
% 	   }
% 	.

itemnames() -> ["Foo", "Bar", "Baz", "Quux", "Maurice"].


run() ->
    gtk:start(),
    spawn_link(?MODULE, main, []).

main( ) ->
    %% a generic toplevel window */
    Window = gtk:window_new ('GTK_WINDOW_TOPLEVEL'),

    gtk:signal_connect (?GTK_OBJECT(Window), 'delete_event',
			fun(_,_,_) -> gtk:main_quit() end, []),
    gtk:container_set_border_width (?GTK_CONTAINER(Window), 5),
    

    %% A generic scrolled window */
    Scrolled_win = gtk:scrolled_window_new (?GTK_NULL, ?GTK_NULL),
    gtk:scrolled_window_set_policy (?GTK_SCROLLED_WINDOW (Scrolled_win),
				    'GTK_POLICY_AUTOMATIC',
				    'GTK_POLICY_AUTOMATIC'),
    gtk:widget_set_usize (Scrolled_win, 150, 200),
    gtk:container_add (?GTK_CONTAINER(Window), Scrolled_win),
    gtk:widget_show (Scrolled_win),
  
    %% Create the root tree */
    Tree = gtk:tree_new(),
    io:format("root tree is ~p\n", [Tree]),
    %% connect all GtkTree:: signals 
    gtk:signal_connect (?GTK_OBJECT(Tree), 'select_child',
			fun cb_select_child/3, Tree),
    gtk:signal_connect (?GTK_OBJECT(Tree), 'unselect_child',
			fun cb_unselect_child/3, Tree),
    gtk:signal_connect (?GTK_OBJECT(Tree), 'selection_changed',
			fun cb_selection_changed/2, Tree),
    %% Add it to the scrolled window 
    gtk:scrolled_window_add_with_viewport(?GTK_SCROLLED_WINDOW(Scrolled_win),
					  Tree),
    %% Set the selection mode 
    gtk:tree_set_selection_mode(?GTK_TREE(Tree),
				'GTK_SELECTION_MULTIPLE'),
    %% Show it 
    gtk:widget_show (Tree),
    
    lists:foreach(
      fun(ItemName) ->
	      %% Create a tree item 
	      Item = gtk:tree_item_new_with_label(ItemName),
	      %% Connect all GtkItem:: and GtkTreeItem:: signals 
	      gtk:signal_connect (?GTK_OBJECT(Item), 'select',
				  fun cb_itemsignal/2, "select"),
	      gtk:signal_connect (?GTK_OBJECT(Item), 'deselect',
				  fun cb_itemsignal/2, "deselect"),
	      gtk:signal_connect (?GTK_OBJECT(Item), 'toggle',
				  fun cb_itemsignal/2, "toggle"),
	      gtk:signal_connect (?GTK_OBJECT(Item), 'expand',
				  fun cb_itemsignal/2, "expand"),
	      gtk:signal_connect (?GTK_OBJECT(Item), 'collapse',
				  fun cb_itemsignal/2, "collapse"),
	      %% Add it to the parent tree 
	      gtk:tree_append (?GTK_TREE(Tree), Item),
	      %% Show it - this can be done at any time 
	      gtk:widget_show (Item),
	      %% Create this item's subtree 
	      Subtree = gtk:tree_new(),
	      io:format ("-> item ~s->~p, subtree ~p\n", 
			 [ItemName, Item, Subtree]),

	      %% This is still necessary if you want these signals to be called
	      %% for the subtree's children. Note that selection_change will be
	      %% signalled for the root tree regardless. 
	      gtk:signal_connect (?GTK_OBJECT(Subtree), 'select_child',
				  fun cb_select_child/3, Subtree),
	      gtk:signal_connect (?GTK_OBJECT(Subtree), 'unselect_child',
				  fun cb_unselect_child/3, Subtree),
	      %% This has absolutely no effect, because it is completely 
	      %% ignored in subtrees 
	      gtk:tree_set_selection_mode(?GTK_TREE(Subtree),
					  'GTK_SELECTION_SINGLE'),
	      %% Neither does this, but for a rather different reason - the
	      %% view_mode and view_line values of a tree are propagated to
	      %% subtrees when they are mapped.  So, setting it later on would
	      %% actually have a (somewhat unpredictable) effect 
	      gtk:tree_set_view_mode (?GTK_TREE(Subtree),'GTK_TREE_VIEW_ITEM'),
	      %% Set this item's subtree - note that you cannot do this until
	      %% AFTER the item has been added to its parent tree! 
	      gtk:tree_item_set_subtree (?GTK_TREE_ITEM(Item), Subtree),

	      lists:foreach(
		fun(Name) ->
			%% Create a subtree item, in much the same way */
			SubItem = gtk:tree_item_new_with_label(Name),
			%% Connect all GtkItem:: and GtkTreeItem:: signals 
			gtk:signal_connect (?GTK_OBJECT(SubItem), 'select',
					    fun cb_itemsignal/2, "select"),
			gtk:signal_connect (?GTK_OBJECT(SubItem), 'deselect',
					    fun cb_itemsignal/2, "deselect"),
			gtk:signal_connect (?GTK_OBJECT(SubItem), 'toggle',
					    fun cb_itemsignal/2, "toggle"),
			gtk:signal_connect (?GTK_OBJECT(SubItem), 'expand',
					    fun cb_itemsignal/2, "expand"),
			gtk:signal_connect (?GTK_OBJECT(SubItem), 'collapse',
					    fun cb_itemsignal/2, "collapse"),
			io:format("-> -> item ~s->~p\n",
				  [Name, SubItem]),
			%% Add it to its parent tree 
			gtk:tree_append (?GTK_TREE(Subtree), SubItem),
			%% Show it 
			gtk:widget_show (SubItem)
		end, itemnames())
      end, itemnames()),
    
    %% Show the window and loop endlessly 
    gtk:widget_show (Window),
    gtk:main(),
    0.

%% example-end 
