
module gdk_pixbuf;

#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk-pixbuf/gdk-pixbuf-loader.h>
#include "../gdk_pixbuf/gdrv_gdk_pixbuf.h"

typedef GtkObject GdkPixbufAnimation;
typedef GtkObject GdkPixbufAnimationIter;

struct GError
{
  GQuark       domain;
  gint         code;
  gchar       *message;
};

struct GTimeVal
{
    glong tv_sec;
    glong tv_usec;
};

enum GdkColorspace {
    GDK_COLORSPACE_RGB
};

enum GdkPixbufAlphaMode {
    GDK_PIXBUF_ALPHA_BILEVEL,
    GDK_PIXBUF_ALPHA_FULL
};

enum GdkInterpType {
    GDK_INTERP_NEAREST,
    GDK_INTERP_TILES,
    GDK_INTERP_BILINEAR,
    GDK_INTERP_HYPER
};

GdkPixbuf *gdk_pixbuf_ref      (GdkPixbuf *pixbuf);
void       gdk_pixbuf_unref    (GdkPixbuf *pixbuf);

/* No callbacks YET 
void gdk_pixbuf_set_last_unref_handler (GdkPixbuf          *pixbuf,
                                        GdkPixbufLastUnref  last_unref_fn,
					gpointer          last_unref_fn_data);
*/
 
/* void       gdk_pixbuf_finalize (GdkPixbuf *pixbuf); */


/* GdkPixbuf accessors */

GdkColorspace gdk_pixbuf_get_colorspace      (const GdkPixbuf *pixbuf);
int           gdk_pixbuf_get_n_channels      (const GdkPixbuf *pixbuf);
gboolean      gdk_pixbuf_get_has_alpha       (const GdkPixbuf *pixbuf);
int           gdk_pixbuf_get_bits_per_sample (const GdkPixbuf *pixbuf);
void*         gdk_pixbuf_get_pixels          (const GdkPixbuf *pixbuf) = gdrv_gdk_pixbuf_get_pixels;
int           gdk_pixbuf_get_width           (const GdkPixbuf *pixbuf);
int           gdk_pixbuf_get_height          (const GdkPixbuf *pixbuf);
int           gdk_pixbuf_get_rowstride       (const GdkPixbuf *pixbuf);


GdkPixbuf *gdk_pixbuf_new (GdkColorspace colorspace, gboolean has_alpha, 
			   int bits_per_sample, int width, int height);

GdkPixbuf *gdk_pixbuf_copy (const GdkPixbuf *pixbuf);

GdkPixbuf *gdk_pixbuf_new_from_file (const char *filename, GError** error);

/* can not handle callbacks YET 
GdkPixbuf *gdk_pixbuf_new_from_data (const guchar *data,
                                     GdkColorspace colorspace,
                                     gboolean has_alpha,
                                     int bits_per_sample,
                                     int width, int height,
                                     int rowstride,
                                     GdkPixbufDestroyNotify destroy_fn,
                                     gpointer destroy_fn_data);
*/

GdkPixbuf *gdk_pixbuf_new_from_xpm_data (const char **data);
GdkPixbuf* gdk_pixbuf_new_from_inline   (gint          data_length,
                                         const guint8 *data,
                                         gboolean      copy_pixels,
                                         GError      **error);
/* Mutations */
void       gdk_pixbuf_fill              (GdkPixbuf    *pixbuf,
                                         guint32       pixel);

/* Saving */

gboolean gdk_pixbuf_save           (GdkPixbuf  *pixbuf, 
                                    const char *filename, 
                                    const char *type, 
                                    GError    **error); /*...); */

gboolean gdk_pixbuf_savev          (GdkPixbuf  *pixbuf, 
                                    const char *filename, 
                                    const char *type,
                                    char      **option_keys,
                                    char      **option_values,
                                    GError    **error);

/* Adding an alpha channel */
GdkPixbuf *gdk_pixbuf_add_alpha (const GdkPixbuf *pixbuf, gboolean substitute_color,
                                 guchar r, guchar g, guchar b);

/* Copy an area of a pixbuf onto another one */
void gdk_pixbuf_copy_area (const GdkPixbuf *src_pixbuf,
                           int src_x, int src_y,
                           int width, int height,
                           GdkPixbuf *dest_pixbuf,
                           int dest_x, int dest_y);

/* Brighten/darken and optionally make it pixelated-looking */
void gdk_pixbuf_saturate_and_pixelate (const GdkPixbuf *src,
                                       GdkPixbuf       *dest,
                                       gfloat           saturation,
                                       gboolean         pixelate);
/* Interpolation modes */
enum GdkInterpType {
        GDK_INTERP_NEAREST,
        GDK_INTERP_TILES,
        GDK_INTERP_BILINEAR,
        GDK_INTERP_HYPER
};

void gdk_pixbuf_scale           (const GdkPixbuf *src,
                                 GdkPixbuf       *dest,
                                 int              dest_x,
                                 int              dest_y,
                                 int              dest_width,
                                 int              dest_height,
                                 double           offset_x,
                                 double           offset_y,
                                 double           scale_x,
                                 double           scale_y,
                                 GdkInterpType    interp_type);
void gdk_pixbuf_composite       (const GdkPixbuf *src,
                                 GdkPixbuf       *dest,
                                 int              dest_x,
                                 int              dest_y,
                                 int              dest_width,
                                 int              dest_height,
                                 double           offset_x,
                                 double           offset_y,
                                 double           scale_x,
                                 double           scale_y,
                                 GdkInterpType    interp_type,
                                 int              overall_alpha);
void gdk_pixbuf_composite_color (const GdkPixbuf *src,
                                 GdkPixbuf       *dest,
                                 int              dest_x,
                                 int              dest_y,
                                 int              dest_width,
                                 int              dest_height,
                                 double           offset_x,
                                 double           offset_y,
                                 double           scale_x,
                                 double           scale_y,
                                 GdkInterpType    interp_type,
                                 int              overall_alpha,
                                 int              check_x,
                                 int              check_y,
                                 int              check_size,
                                 guint32          color1,
                                 guint32          color2);


GdkPixbuf *gdk_pixbuf_scale_simple           (const GdkPixbuf *src,
                                              int              dest_width,
                                              int              dest_height,
                                              GdkInterpType    interp_type);

GdkPixbuf *gdk_pixbuf_composite_color_simple (const GdkPixbuf *src,
                                              int              dest_width,
                                              int              dest_height,
                                              GdkInterpType    interp_type,
                                              int              overall_alpha,
                                              int              check_size,
                                              guint32          color1,
                                              guint32          color2);

/* Animation support */

GdkPixbufAnimation *gdk_pixbuf_animation_new_from_file   (const char         *filename,
                                                          GError            **error);


GdkPixbufAnimation *gdk_pixbuf_animation_ref             (GdkPixbufAnimation *animation);
void                gdk_pixbuf_animation_unref           (GdkPixbufAnimation *animation);


int                 gdk_pixbuf_animation_get_width       (GdkPixbufAnimation *animation);
int                 gdk_pixbuf_animation_get_height      (GdkPixbufAnimation *animation);
gboolean            gdk_pixbuf_animation_is_static_image  (GdkPixbufAnimation *animation);
GdkPixbuf          *gdk_pixbuf_animation_get_static_image (GdkPixbufAnimation *animation);

GdkPixbufAnimationIter *gdk_pixbuf_animation_get_iter                        (GdkPixbufAnimation     *animation,
                                                                              const GTimeVal         *start_time);

int                     gdk_pixbuf_animation_iter_get_delay_time             (GdkPixbufAnimationIter *iter);
GdkPixbuf              *gdk_pixbuf_animation_iter_get_pixbuf                 (GdkPixbufAnimationIter *iter);
gboolean                gdk_pixbuf_animation_iter_on_currently_loading_frame (GdkPixbufAnimationIter *iter);
gboolean                gdk_pixbuf_animation_iter_advance                    (GdkPixbufAnimationIter *iter,
                                                                              const GTimeVal         *current_time);

gchar * gdk_pixbuf_get_option (GdkPixbuf   *pixbuf,
			       const gchar *key);
