%%
%% THE BIT NUMBERS MUST BE KEPT IN SYNC WITH inet_drv.c!!!!
%%
%%
%% definitions of "recognised" hdr fields
%% HTTP_HDR_x == atom value of header field name
%% HTTP_STR_x == string value of header field name
%% HTTP_BIT_x == bit number of header field name
%%
%% General
-define(HTTP_BIT_CACHE_CONTROL,      1).
-define(HTTP_BIT_CONNECTION,         2).
-define(HTTP_BIT_DATE,               3).
-define(HTTP_BIT_PRAGMA,             4).
-define(HTTP_BIT_TRANSFER_ENCODING,  5).
-define(HTTP_BIT_UPGRADE,            6).
-define(HTTP_BIT_VIA,                7).
%% Request
-define(HTTP_BIT_ACCEPT,             8).
-define(HTTP_BIT_ACCEPT_CHARSET,     9).
-define(HTTP_BIT_ACCEPT_ENCODING,    10).
-define(HTTP_BIT_ACCEPT_LANGUAGE,    11).
-define(HTTP_BIT_AUTHORIZATION,      12).
-define(HTTP_BIT_FROM,               13).
-define(HTTP_BIT_HOST,               14).
-define(HTTP_BIT_IF_MODIFIED_SINCE,  15).
-define(HTTP_BIT_IF_MATCH,           16).
-define(HTTP_BIT_IF_NONE_MATCH,      17).
-define(HTTP_BIT_IF_RANGE,           18).
-define(HTTP_BIT_IF_UNMODIFIED_SINCE,19).
-define(HTTP_BIT_MAX_FORWARDS,       20).
-define(HTTP_BIT_PROXY_AUTHORIZATION,21).
-define(HTTP_BIT_RANGE,              22).
-define(HTTP_BIT_REFERER,            23).
-define(HTTP_BIT_USER_AGENT,         24).
%% Response
-define(HTTP_BIT_AGE,                25).
-define(HTTP_BIT_LOCATION,           26).
-define(HTTP_BIT_PROXY_AUTHENTICATE, 27).
-define(HTTP_BIT_PUBLIC,             28).
-define(HTTP_BIT_RETRY_AFTER,        29).
-define(HTTP_BIT_SERVER,             30).
-define(HTTP_BIT_VARY,               31).
-define(HTTP_BIT_WARNING,            32).
-define(HTTP_BIT_WWW_AUTHENTICATE,   33).
%% Entity
-define(HTTP_BIT_ALLOW,              34).
-define(HTTP_BIT_CONTENT_BASE,       35).
-define(HTTP_BIT_CONTENT_ENCODING,   36).
-define(HTTP_BIT_CONTENT_LANGUAGE,   37).
-define(HTTP_BIT_CONTENT_LENGTH,     38).
-define(HTTP_BIT_CONTENT_LOCATION,   39).
-define(HTTP_BIT_CONTENT_MD5,        40).
-define(HTTP_BIT_CONTENT_RANGE,      41).
-define(HTTP_BIT_CONTENT_TYPE,       42).
-define(HTTP_BIT_ETAG,               43).
-define(HTTP_BIT_EXPIRES,            44).
-define(HTTP_BIT_LAST_MODIFIED,      45).
%% Other
-define(HTTP_BIT_ACCEPT_RANGES,      46).
-define(HTTP_BIT_SET_COOKIE,         47).
-define(HTTP_BIT_SET_COOKIE2,        48).
-define(HTTP_BIT_X_FORWARDED_FOR,    49).
-define(HTTP_BIT_COOKIE,             50).
-define(HTTP_BIT_KEEP_ALIVE,         51).
-define(HTTP_BIT_PROXY_CONNECTION,   52).

-define(HTTP_BITS,                   52).
%% Create a bitmask
-define(BIT_MASK(B), (1 bsl (B))).

%% Header encoding
-define(HTTP_HDR_CACHE_CONTROL,	      'Cache-Control').
-define(HTTP_HDR_CONNECTION,	      'Connection').
-define(HTTP_HDR_DATE,	              'Date').
-define(HTTP_HDR_PRAGMA,	      'Pragma').
-define(HTTP_HDR_TRANSFER_ENCODING,   'Transfer-Encoding').
-define(HTTP_HDR_UPGRADE,	      'Upgrade').
-define(HTTP_HDR_VIA,	              'Via').
%% Request header fields
-define(HTTP_HDR_ACCEPT,	      'Accept').
-define(HTTP_HDR_ACCEPT_CHARSET,      'Accept-Charset').
-define(HTTP_HDR_ACCEPT_ENCODING,     'Accept-Encoding').
-define(HTTP_HDR_ACCEPT_LANGUAGE,     'Accept-Language').
-define(HTTP_HDR_AUTHORIZATION,	      'Authorization').
-define(HTTP_HDR_FROM,	              'From').
-define(HTTP_HDR_HOST,	              'Host').
-define(HTTP_HDR_IF_MODIFIED_SINCE,   'If-Modified-Since').
-define(HTTP_HDR_IF_MATCH,	      'If-Match').
-define(HTTP_HDR_IF_NONE_MATCH,	      'If-None-Match').
-define(HTTP_HDR_IF_RANGE,	      'If-Range').
-define(HTTP_HDR_IF_UNMODIFIED_SINCE, 'If-Unmodified-Since').
-define(HTTP_HDR_MAX_FORWARDS,	      'Max-Forwards').
-define(HTTP_HDR_PROXY_AUTHORIZATION, 'Proxy-Authorization').
-define(HTTP_HDR_RANGE,               'Range').
-define(HTTP_HDR_REFERER,	      'Referer').
-define(HTTP_HDR_USER_AGENT,	      'User-Agent').
	
%% Response header fields
-define(HTTP_HDR_AGE,	            'Age').
-define(HTTP_HDR_LOCATION,	    'Location').
-define(HTTP_HDR_PROXY_AUTHENTICATE,'Proxy-Authenticate').
-define(HTTP_HDR_PUBLIC,	    'Public').
-define(HTTP_HDR_RETRY_AFTER,	    'Retry-After').
-define(HTTP_HDR_SERVER,	    'Server').
-define(HTTP_HDR_VARY,	            'Vary').
-define(HTTP_HDR_WARNING,	    'Warning').
-define(HTTP_HDR_WWW_AUTHENTICATE,  'Www-Authenticate').

%% Entity header fields
-define(HTTP_HDR_ALLOW,	            'Allow').
-define(HTTP_HDR_CONTENT_BASE,      'Content-Base').
-define(HTTP_HDR_CONTENT_ENCODING,  'Content-Encoding').
-define(HTTP_HDR_CONTENT_LANGUAGE,  'Content-Language').
-define(HTTP_HDR_CONTENT_LENGTH,    'Content-Length').
-define(HTTP_HDR_CONTENT_LOCATION,  'Content-Location').
-define(HTTP_HDR_CONTENT_MD5,       'Content-Md5').
-define(HTTP_HDR_CONTENT_RANGE,     'Content-Range').
-define(HTTP_HDR_CONTENT_TYPE,      'Content-Type').
-define(HTTP_HDR_ETAG,              'Etag').
-define(HTTP_HDR_EXPIRES,           'Expires').
-define(HTTP_HDR_LAST_MODIFIED,     'Last-Modified').
%% Other optional header fields
-define(HTTP_HDR_ACCEPT_RANGES,     'Accept-Ranges').
-define(HTTP_HDR_SET_COOKIE,        'Set-Cookie').
-define(HTTP_HDR_SET_COOKIE2,	    'Set-Cookie2').
-define(HTTP_HDR_X_FORWARDED_FOR,   'X-Forwarded-For').
-define(HTTP_HDR_COOKIE,	    'Cookie').
-define(HTTP_HDR_KEEP_ALIVE,	    'Keep-Alive').
-define(HTTP_HDR_PROXY_CONNECTION,  'Proxy-Connection').
