/*
 * wrapper module for "hard to automate" functions
 *
 */

#include <GL/gl.h>
#include "gtk_drv_api.h"

static int vector_get_size(GLenum pname)
{
    switch(pname) {
    case GL_DEPTH_RANGE: 
    case GL_LINE_WIDTH_RANGE:
    case GL_MAP2_GRID_SEGMENTS:
    case GL_MAX_VIEWPORT_DIMS:
    case GL_POINT_SIZE_RANGE:
    case GL_POLYGON_MODE:
	return 2;
    case GL_CURRENT_NORMAL:
	return 3;
    case GL_ACCUM_CLEAR_VALUE:
#ifndef _WIN32
    case GL_BLEND_COLOR_EXT:
#endif
    case GL_COLOR_CLEAR_VALUE: 
    case GL_COLOR_WRITEMASK:
    case GL_CURRENT_COLOR:  
    case GL_CURRENT_RASTER_COLOR:
    case GL_CURRENT_RASTER_POSITION:
    case GL_CURRENT_RASTER_TEXTURE_COORDS:
    case GL_CURRENT_TEXTURE_COORDS:  
    case GL_FOG_COLOR:
    case GL_LIGHT_MODEL_AMBIENT:
    case GL_MAP2_GRID_DOMAIN:
    case GL_SCISSOR_BOX:
    case GL_VIEWPORT:
	return 4;
    case GL_MODELVIEW_MATRIX:
    case GL_PROJECTION_MATRIX:
    case GL_TEXTURE_MATRIX:
	return 16;
    default: 
	return 1;
    }
}

void gdrv_glGetFloatv(GLenum pname, GtkArray *arr)
{
    arr->size   = vector_get_size(pname);
    arr->vector = gdrv_stack_alloc(arr->size*sizeof(GLfloat));
    glGetFloatv(pname, (GLfloat*) arr->vector);
}

void gdrv_glGetDoublev(GLenum pname, GtkArray *arr)
{
    arr->size   = vector_get_size(pname);
    arr->vector = gdrv_stack_alloc(arr->size*sizeof(GLdouble));
    glGetDoublev(pname, (GLdouble*) arr->vector);
}

void gdrv_glGetIntegerv(GLenum pname, GtkArray *arr)
{
    arr->size   = vector_get_size(pname);
    arr->vector = gdrv_stack_alloc(arr->size*sizeof(GLint));
    glGetIntegerv(pname, (GLint*) arr->vector);
}

void gdrv_glGetBooleanv(GLenum pname, GtkArray *arr)
{
    arr->size   = vector_get_size(pname);
    arr->vector = gdrv_stack_alloc(arr->size*sizeof(GLboolean));
    glGetBooleanv(pname, (GLboolean*) arr->vector);
}


void gdrv_glGenTextures(GLsizei n, GtkArray* arr) 
{
    arr->size   = n;
    arr->vector = gdrv_stack_alloc(arr->size*sizeof(GLint));
    glGenTextures(n, (GLint*) arr->vector);
}


void gdrv_glReadPixels( GLint x, GLint y,
		       GLsizei width, GLsizei height,
		       GLenum format, GLenum type,
		       GtkArray* arr)
{
    /* FIXME */
    arr->size = 0;
    arr->vector = NULL;
    glReadPixels(x, y, width, height, format, type, NULL);    
}


void gdrv_glGetTexImage( GLenum target, GLint level,
			GLenum format, GLenum type,
			GtkArray* arr)
{
    /* FIXME */
    arr->size = 0;
    arr->vector = NULL;
    glGetTexImage(target, level, format, type, NULL);
}

void gdrv_glGetPointerv(GLenum pname, GtkArray* arr)
{
    /* FIXME */
    arr->size = 0;
    arr->vector = NULL;
    glGetPointerv(pname, NULL);
}

