
module glu;

#include <GL/gl.h>
#include <GL/glu.h>

/* FIXME: add include ??? */
typedef unsigned int  GLenum;
typedef unsigned char GLboolean;
typedef GtkFlags      GLbitfield;
typedef void          GLvoid;
typedef char          GLbyte;
typedef int           GLshort;  /* there are no GTK_TYPE_SHORT !! */
typedef int           GLint;
typedef unsigned char GLubyte;
typedef unsigned int  GLushort;   /* there are no GTK_TYPE_SHORT !! */
typedef unsigned int  GLuint;
typedef int           GLsizei;
typedef float         GLfloat;
typedef float         GLclampf;
typedef double        GLdouble;
typedef double        GLclampd;

/*
 * These are the GLU 1.1 typedefs.  GLU 1.2 has different ones!
 */
/***
typedef struct GLUquadricObj      GLUquadricObj;
typedef struct GLUtriangulatorObj GLUtriangulatorObj;
typedef struct GLUnurbsObj        GLUnurbsObj;
***/

typedef gpointer GLUquadricObj;
typedef gpointer GLUtriangulatorObj;
typedef gpointer GLUnurbsObj;


void  gluLookAt( GLdouble eyex, GLdouble eyey, GLdouble eyez,
		GLdouble centerx, GLdouble centery,
		GLdouble centerz,
		GLdouble upx, GLdouble upy, GLdouble upz );

void  gluOrtho2D( GLdouble left, GLdouble right,
		 GLdouble bottom, GLdouble top );

void  gluPerspective( GLdouble fovy, GLdouble aspect,
		     GLdouble zNear, GLdouble zFar );

void  gluPickMatrix( GLdouble x, GLdouble y,
		    GLdouble width, GLdouble height,
		    const GLint viewport[4] );

GLint  gluProject( GLdouble objx, GLdouble objy, GLdouble objz,
		  const GLdouble modelMatrix[16],
		  const GLdouble projMatrix[16],
		  const GLint viewport[4],
		  out GLdouble winx, out GLdouble winy,
		  out GLdouble winz );

GLint  gluUnProject(GLdouble winx, GLdouble winy,
		    GLdouble winz,
		    const GLdouble modelMatrix[16],
		    const GLdouble projMatrix[16],
		    const GLint viewport[4],
		    out GLdouble objx, out GLdouble objy,
		    out GLdouble objz );

const GLubyte*  gluErrorString( GLenum errorCode );

/*
 *
 * Mipmapping and image scaling
 *
 */

/**************
GLint  gluScaleImage( GLenum format,
		     GLint widthin, GLint heightin,
		     GLenum typein, const void *datain,
		     GLint widthout, GLint heightout,
		     GLenum typeout, void *dataout );

GLint  gluBuild1DMipmaps( GLenum target, GLint components,
			 GLint width, GLenum format,
			 GLenum type, const void *data );

GLint  gluBuild2DMipmaps( GLenum target, GLint components,
			 GLint width, GLint height,
			 GLenum format,
			 GLenum type, const void *data );

**********/

/*
 *
 * Quadrics
 *
 */

GLUquadricObj*  gluNewQuadric( void );

void  gluDeleteQuadric( GLUquadricObj *state );

void  gluQuadricDrawStyle( GLUquadricObj *quadObject,
			  GLenum drawStyle );

void  gluQuadricOrientation( GLUquadricObj *quadObject,
			    GLenum orientation );

void  gluQuadricNormals( GLUquadricObj *quadObject,
			GLenum normals );

void  gluQuadricTexture( GLUquadricObj *quadObject,
			GLboolean textureCoords );
/*****
void  gluQuadricCallback( GLUquadricObj *qobj,
			 GLenum which, void (*fn)() );
****/
void  gluCylinder( GLUquadricObj *qobj,
		  GLdouble baseRadius,
		  GLdouble topRadius,
		  GLdouble height,
		  GLint slices, GLint stacks );

void  gluSphere( GLUquadricObj *qobj,
		GLdouble radius, GLint slices, GLint stacks );

void  gluDisk( GLUquadricObj *qobj,
	      GLdouble innerRadius, GLdouble outerRadius,
	      GLint slices, GLint loops );

void  gluPartialDisk( GLUquadricObj *qobj, GLdouble innerRadius,
		     GLdouble outerRadius, GLint slices,
		     GLint loops, GLdouble startAngle,
		     GLdouble sweepAngle );



/*
 *
 * Nurbs
 *
 */

GLUnurbsObj*  gluNewNurbsRenderer( void );

void  gluDeleteNurbsRenderer( GLUnurbsObj *nobj );

void  gluLoadSamplingMatrices( GLUnurbsObj *nobj,
			      const GLfloat modelMatrix[16],
			      const GLfloat projMatrix[16],
			      const GLint viewport[4] );

void  gluNurbsProperty( GLUnurbsObj *nobj, GLenum property,
		       GLfloat value );

void  gluGetNurbsProperty( GLUnurbsObj *nobj, GLenum property,
			   out GLfloat *value );

void  gluBeginCurve( GLUnurbsObj *nobj );

void  gluEndCurve( GLUnurbsObj * nobj );

void  gluNurbsCurve( GLUnurbsObj *nobj, GLint nknots,
		    GLfloat *knot, GLint stride,
		    GLfloat *ctlarray, GLint order,
		    GLenum type );

void  gluBeginSurface( GLUnurbsObj *nobj );

void  gluEndSurface( GLUnurbsObj * nobj );

void  gluNurbsSurface( GLUnurbsObj *nobj,
		      GLint sknot_count, GLfloat *sknot,
		      GLint tknot_count, GLfloat *tknot,
		      GLint s_stride, GLint t_stride,
		      GLfloat *ctlarray,
		      GLint sorder, GLint torder,
		      GLenum type );

void  gluBeginTrim( GLUnurbsObj *nobj );

void  gluEndTrim( GLUnurbsObj *nobj );

void  gluPwlCurve( GLUnurbsObj *nobj, GLint count,
		  GLfloat *array, GLint stride, GLenum type );
/***
void  gluNurbsCallback( GLUnurbsObj *nobj, GLenum which,
		       void (*fn)() );
***/


/*
 *
 * Polygon tesselation
 *
 */

GLUtriangulatorObj*  gluNewTess( void );
/***
void  gluTessCallback( GLUtriangulatorObj *tobj, GLenum which,
		      void (*fn)() );
***/
void  gluDeleteTess( GLUtriangulatorObj *tobj );

void  gluBeginPolygon( GLUtriangulatorObj *tobj );

void  gluEndPolygon( GLUtriangulatorObj *tobj );

void  gluNextContour( GLUtriangulatorObj *tobj, GLenum type );
/***
void  gluTessVertex( GLUtriangulatorObj *tobj, GLdouble v[3],
		    void *data );
***/

/*
 *
 * New functions in GLU 1.1
 *
 */

const GLubyte*  gluGetString( GLenum name );


