%%% File    : gdk.hrl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Description : Gdk defintions
%%% Created : 22 Mar 2001 by Tony Rogvall <tony@bit.hemma.se>
-ifndef(GDK_HRL).
-define(GDK_HRL, true).

-include_lib("erlgtk/include/libgdk.hrl").

-define(GDK_EXPOSURE_MASK,              (1 bsl 1)).
-define(GDK_POINTER_MOTION_MASK,        (1 bsl 2)).
-define(GDK_POINTER_MOTION_HINT_MASK,   (1 bsl 3)).
-define(GDK_BUTTON_MOTION_MASK,         (1 bsl 4)).
-define(GDK_BUTTON1_MOTION_MASK,        (1 bsl 5)).
-define(GDK_BUTTON2_MOTION_MASK,        (1 bsl 6)).
-define(GDK_BUTTON3_MOTION_MASK,        (1 bsl 7)).
-define(GDK_BUTTON_PRESS_MASK,          (1 bsl 8)).
-define(GDK_BUTTON_RELEASE_MASK,        (1 bsl 9)).
-define(GDK_KEY_PRESS_MASK,             (1 bsl 10)).
-define(GDK_KEY_RELEASE_MASK,           (1 bsl 11)).
-define(GDK_ENTER_NOTIFY_MASK,          (1 bsl 12)).
-define(GDK_LEAVE_NOTIFY_MASK,          (1 bsl 13)).
-define(GDK_FOCUS_CHANGE_MASK,          (1 bsl 14)).
-define(GDK_STRUCTURE_MASK,             (1 bsl 15)).
-define(GDK_PROPERTY_CHANGE_MASK,       (1 bsl 16)).
-define(GDK_VISIBILITY_NOTIFY_MASK,     (1 bsl 17)).
-define(GDK_PROXIMITY_IN_MASK,          (1 bsl 18)).
-define(GDK_PROXIMITY_OUT_MASK,         (1 bsl 19)).
-define(GDK_SUBSTRUCTURE_MASK,          (1 bsl 20)).
-define(GDK_SCOLL_MASK,                 (1 bsl 21)).  % Gtk-2.0 !
-define(GDK_ALL_EVENTS_MASK, 		16#3FFFFE).

%%
%% GdkWindowAttributesType
%%
-define(GDK_WA_TITLE,     (1 bsl 1)).
-define(GDK_WA_X,	  (1 bsl 2)).
-define(GDK_WA_Y,	  (1 bsl 3)).
-define(GDK_WA_CURSOR,	  (1 bsl 4)).
-define(GDK_WA_COLORMAP,  (1 bsl 5)).
-define(GDK_WA_VISUAL,    (1 bsl 6)).
-define(GDK_WA_WMCLASS,   (1 bsl 7)).
-define(GDK_WA_NOREDIR,   (1 bsl 8)).


-define(GDK_HINT_POS,        (1 bsl 0)).
-define(GDK_HINT_MIN_SIZE,   (1 bsl 1)).
-define(GDK_HINT_MAX_SIZE,   (1 bsl 2)).
-define(GDK_HINT_BASE_SIZE,  (1 bsl 3)).
-define(GDK_HINT_ASPECT,     (1 bsl 4)).
-define(GDK_HINT_RESIZE_INC, (1 bsl 5)).

%%
%% GdkEvents
%%
%%

-define(GDK_ACTION_DEFAULT, 2#00000001).
-define(GDK_ACTION_COPY,    2#00000010).
-define(GDK_ACTION_MOVE,    2#00000100).
-define(GDK_ACTION_LINK,    2#00001000).
-define(GDK_ACTION_PRIVATE, 2#00010000).
-define(GDK_ACTION_ASK,     2#00100000).

-record(gdk_drag_context,
	{
	  protocol,
	  is_source,
	  source_window,
	  dest_window,
	  targets,
	  actions,
	  suggested_action,
	  action,
	  start_time
	 }).

-define(GDK_EVENT_TYPE(R), element(#gdk_event_any.type, R)).

%% type: GDK_DELETE, GDK_DESTROY, GDK_MAP, GDK_UNMAP, GDK_NOTHING
-record(gdk_event_any,
	{
	  type,        
	  window,
	  send_event
	 }).

%% type: GDK_EXPOSE
-record(gdk_event_expose,
	{
	  type,
	  window,
	  send_event,
	  area,
	  count
	  }).

%% type: GDK_NO_EXPOSE
-record(gdk_event_no_expose,
	{
	  type,
	  window,
	  send_event
	 }).

%% type: GDK_VISIBILITY_NOTIFY
-record(gdk_event_visiblity,
	{
	  type,      
	  window,    
	  send_event,
	  state
	  }).

%% type: GDK_MOTION_NOIFY
-record(gdk_event_motion,
	{
	  type,       
	  window,     
	  send_event,
	  time,
	  x,
	  y,
	  pressure,
	  xtilt,
	  ytilt,
	  state,
	  is_hint,
	  source,
	  deviceid,
	  x_root,
	  y_root
	 }).

%% type: GDK_BUTTON_PRESS, GDK_2BUTTON_PRESS, GDK_3BUTTON_PRESS, 
%%       GDK_BUTTON_RELEASE
-record(gdk_event_button,
	{
	  type,      
	  window,
	  send_event,
	  time,
	  x,
	  y,
	  pressure,
	  xtilt,
	  ytilt,
	  state,
	  button,
	  source,
	  deviceid,
	  x_root,
	  y_root
	 }).

%% type: GTK_SCROLL  Gtk-2.0
-record(gdk_event_scroll,
	{
	  type,
	  window,
	  send_event,
	  time,
	  x,
	  y,
	  state,
	  direction,
	  deviceid,
	  x_root,
	  y_root
	 }).

%% type: GDK_KEY_PRESS, GDK_KEY_RELEASE
-record(gdk_event_key,
	{
	  type,
	  window,
	  send_event,
	  time,
	  state,
	  keyval,
	  length,
	  string
	  }).

%% type: GDK_ENTER_NOTIFY, GDK_LEAVE_NOTIFY
-record(gdk_event_crossing,
	{
	  type,       
	  window,
	  send_event,
	  subwindow,
	  time,
	  x,
	  y,
	  x_root,
	  y_root,
	  mode,
	  detail,
	  focus,
	  state
	 }).

%% type: GDK_FOCUS_CHANGE, 
-record(gdk_event_focus,
	{
	  type,        
	  window,
	  send_event,
	  in
	 }).

%% type: GDK_CONFIGURE
-record(gdk_event_configure,
	{
	  type,        
	  window,
	  send_event,
	  x,
	  y,
	  width,
	  height
	 }).

%% type: GDK_PROPERTY_NOTIFY
-record(gdk_event_property,
	{
	  type,
	  window,
	  send_event,
	  atom,
	  time,
	  state
	  }).

%% type: GDK_SELECTION_CLEAR, GDK_SELECTION_REQUEST, GDK_SELECTION_NOTIFY
-record(gdk_event_selection,
	{
	  type,
	  window,
	  send_event,
	  selection,
	  target,
	  property,
	  requestor,
	  time
	  }).

%% type: GDK_PROXIMITY_IN, GDK_PROXIMITY_OUT
-record(gdk_event_proximity,
	{
	  type,
	  window,
	  send_event,
	  time,
	  source,
	  deciveid
	  }).

%% type: GDK_CLIENT_EVENT
-record(gdk_event_client,
	{
	  type,
	  window,
	  send_event,
	  message_type,
	  data_format,
	  data
	 }).

%% type: GDK_DRAG_ENTER, GDK_DRAG_LEAVE, GDK_DRAG_MOTION,
%% GDK_DRAG_STATUS, GDK_DRAG_START, GDK_DRAG_FINISHED
-record(gdk_event_dnd,
	{
	  type,   
	  window,
	  send_event,
	  context,
	  time,
	  x_root,
	  y_root
	 }).

-define(GDK_SHIFT_MASK,   (1 bsl 0)).
-define(GDK_LOCK_MASK,    (1 bsl 1)).
-define(GDK_CONTROL_MASK, (1 bsl 2)).
-define(GDK_MOD1_MASK,    (1 bsl 3)).
-define(GDK_MOD2_MASK,    (1 bsl 4)).
-define(GDK_MOD3_MASK,    (1 bsl 5)).
-define(GDK_MOD4_MASK,    (1 bsl 6)).
-define(GDK_MOD5_MASK,    (1 bsl 7)).
-define(GDK_BUTTON1_MASK, (1 bsl 8)).
-define(GDK_BUTTON2_MASK, (1 bsl 9)).
-define(GDK_BUTTON3_MASK, (1 bsl 10)).
-define(GDK_BUTTON4_MASK, (1 bsl 11)).
-define(GDK_BUTTON5_MASK, (1 bsl 12)).
-define(GDK_RELEASE_MASK, (1 bsl 13)).
-define(GDK_MODIFIER_MASK,16#3fff).

-endif.
