%%% File    : gtk.hrl
%%% Author  : Tony Rogvall <tony@bit.hemma.se>
%%% Description : GTK defintions
%%% Created : 11 Apr 2001 by Tony Rogvall <tony@bit.hemma.se>
-ifndef(GTK_HRL).
-define(GTK_HRL, true).

-include_lib("erlgtk/include/libgtk.hrl").

-define(NULL,       0).
-define(GTK_NULL,   {'GtkObject',0}).

-define(GTK_EXPAND, 2#00000001).
-define(GTK_SHRINK, 2#00000010).
-define(GTK_FILL,   2#00000100).

% packer options
-define(GTK_PACK_EXPAND, 2#00000001). %% nick=expand 
-define(GTK_FILL_X,      2#00000010).
-define(GTK_FILL_Y,      2#00000100).

%% object flags
-define(GTK_DESTROYED,   (1 bsl 0)).
-define(GTK_FLOATING,	 (1 bsl 1)).
-define(GTK_CONNECTED,	 (1 bsl 2)).
-define(GTK_CONSTRUCTED, (1 bsl 3)).

-define(GTK_OBJECT_FLAGS(X), gtk:object_get_flags((X))).

-define(GTK_TOPLEVEL,         (1 bsl 4)).
-define(GTK_NO_WINDOW,        (1 bsl 5)).
-define(GTK_REALIZED,         (1 bsl 6)).
-define(GTK_MAPPED,           (1 bsl 7)).
-define(GTK_VISIBLE,          (1 bsl 8)).
-define(GTK_SENSITIVE,        (1 bsl 9)).
-define(GTK_PARENT_SENSITIVE, (1 bsl 10)).
-define(GTK_CAN_FOCUS,        (1 bsl 11)).
-define(GTK_HAS_FOCUS,        (1 bsl 12)).
-define(GTK_CAN_DEFAULT,      (1 bsl 13)).
-define(GTK_HAS_DEFAULT,      (1 bsl 14)).
-define(GTK_HAS_GRAB,	      (1 bsl 15)).
-define(GTK_RC_STYLE,	      (1 bsl 16)).
-define(GTK_COMPOSITE_CHILD,  (1 bsl 17)).
-define(GTK_NO_REPARENT,      (1 bsl 18)).
-define(GTK_APP_PAINTABLE,    (1 bsl 19)).
-define(GTK_RECEIVES_DEFAULT, (1 bsl 20)).

-define(GTK_WIDGET_SET_FLAGS(X, F),   gtk:widget_set_flags((X),(F))).
-define(GTK_WIDGET_UNSET_FLAGS(X, F), gtk:widget_unset_flags((X),(F))).
-define(GTK_WIDGET_STATE(X),          gtk:widget_get_state((X))).
-define(GTK_WIDGET_SAVED_STATE(X),    gtk:widget_get_saved_state((X))).
-define(GTK_WIDGET_FLAGS(X),          gtk:widget_get_flags((X))).

-define(GTK_WIDGET_TOPLEVEL(X),	          ((?GTK_WIDGET_FLAGS(X) band ?GTK_TOPLEVEL) =/= 0)).
-define(GTK_WIDGET_NO_WINDOW(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_NO_WINDOW) =/= 0)).
-define(GTK_WIDGET_REALIZED(X),	          ((?GTK_WIDGET_FLAGS (X) band ?GTK_REALIZED) =/= 0)).
-define(GTK_WIDGET_MAPPED(X),		  ((?GTK_WIDGET_FLAGS (X) band ?GTK_MAPPED) =/= 0)).
-define(GTK_WIDGET_VISIBLE(X),		  ((?GTK_WIDGET_FLAGS (X) band ?GTK_VISIBLE) =/= 0)).
-define(GTK_WIDGET_DRAWABLE(X),	          (?GTK_WIDGET_VISIBLE (X) and ?GTK_WIDGET_MAPPED (X))).
-define(GTK_WIDGET_SENSITIVE(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_SENSITIVE) =/= 0)).
-define(GTK_WIDGET_PARENT_SENSITIVE(X),   ((?GTK_WIDGET_FLAGS (X) band ?GTK_PARENT_SENSITIVE) =/= 0)).
-define(GTK_WIDGET_IS_SENSITIVE(X),	  (?GTK_WIDGET_SENSITIVE (X) and ?GTK_WIDGET_PARENT_SENSITIVE(X))).
-define(GTK_WIDGET_CAN_FOCUS(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_CAN_FOCUS) =/= 0)).
-define(GTK_WIDGET_HAS_FOCUS(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_HAS_FOCUS) =/= 0)).
-define(GTK_WIDGET_CAN_DEFAULT(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_CAN_DEFAULT) =/= 0)).
-define(GTK_WIDGET_HAS_DEFAULT(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_HAS_DEFAULT) =/= 0)).
-define(GTK_WIDGET_HAS_GRAB(X),	          ((?GTK_WIDGET_FLAGS (X) band ?GTK_HAS_GRAB) =/= 0)).
-define(GTK_WIDGET_RC_STYLE(X),	          ((?GTK_WIDGET_FLAGS (X) band ?GTK_RC_STYLE) =/= 0)).
-define(GTK_WIDGET_COMPOSITE_CHILD(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_COMPOSITE_CHILD) =/= 0)).
-define(GTK_WIDGET_APP_PAINTABLE(X),	  ((?GTK_WIDGET_FLAGS (X) band ?GTK_APP_PAINTABLE) =/= 0)).
-define(GTK_WIDGET_RECEIVES_DEFAULT(X),   ((?GTK_WIDGET_FLAGS(X) band ?GTK_RECEIVES_DEFAULT) =/= 0)).

-define(GTK_ACCEL_VISIBLE,        (1 bsl 0)).
-define(GTK_ACCEL_SIGNAL_VISIBLE, (1 bsl 1)).
-define(GTK_ACCEL_LOCKED,         (1 bsl 2)).
-define(GTK_ACCEL_MASK,           16#07).

-record(gtk_widget_shape_info,
	{
	  offset_x,
	  offset_y,
	  shape_mask
	 }).


%% Casting debug macros

-ifdef(debug).
-define(GTK_CAST(X, Type), 
	case gtk:is_a((X), (Type)) of
	    true -> (X);
	    false -> exit({bad_cast, (X), (Type)})
	end).	
-else.
-define(GTK_CAST(X, Type), (X)).
-endif.

-define(GTK_OBJECT(X), ?GTK_CAST((X), 'GtkObject')).
-define(GTK_IS_OBJECT(X), gtk:is_a((X),'GtkObject')).

-define(GTK_WIDGET(X), ?GTK_CAST((X), 'GtkWidget')).
-define(GTK_IS_WIDGET(X), gtk:is_a((X),'GtkWidget')).

-define(GTK_WINDOW(X), ?GTK_CAST((X), 'GtkWindow')).
-define(GTK_IS_WINDOW(X), gtk:is_a((X),'GtkWindow')).

-define(GTK_CONTAINER(X), ?GTK_CAST((X), 'GtkContainer')).
-define(GTK_IS_CONTAINER(X), gtk:is_a((X),'GtkContainer')).

-define(GTK_SCROLLED_WINDOW(X), ?GTK_CAST((X), 'GtkScrolledWindow')).
-define(GTK_IS_SCROLLED_WINDOW(X), gtk:is_a((X),'GtkScrolledWindow')).

-define(GTK_DIALOG(X), ?GTK_CAST((X), 'GtkDialog')).
-define(GTK_IS_DIALOG(X), gtk:is_a((X),'GtkDialog')).

-define(GTK_FILE_SELECTION(X), ?GTK_CAST((X), 'GtkFileSelection')).
-define(GTK_IS_FILE_SELECTION(X), gtk:is_a((X), 'GtkFileSelection')).

-define(GTK_TREE(X), ?GTK_CAST((X), 'GtkTree')).
-define(GTK_IS_TREE(X), gtk:is_a((X),'GtkTree')).

-define(GTK_TREE_ITEM(X), ?GTK_CAST((X), 'GtkTreeItem')).
-define(GTK_IS_TREE_ITEM(X), gtk:is_a((X), 'GtkTreeItem')).

-define(GTK_COMBO(X), ?GTK_CAST((X),'GtkCombo')).
-define(GTK_IS_COMBO(X), gtk:is_a((X),'GtkCombo')).

-define(GTK_RANGE(X), ?GTK_CAST((X), 'GtkRange')).
-define(GTK_SCALE(X), ?GTK_CAST((X), 'GtkScale')).
-define(GTK_BOX(X), ?GTK_CAST((X), 'GtkBox')).
-define(GTK_STATUSBAR(X), ?GTK_CAST((X), 'GtkStatusbar')).
-define(GTK_TEXT(X), ?GTK_CAST((X), 'GtkText')).
-define(GTK_TOGGLE_BUTTON(X), ?GTK_CAST((X), 'GtkToggleButton')).
-define(GTK_EDITABLE(X), ?GTK_CAST((X), 'GtkEditable')).
-define(GTK_TABLE(X), ?GTK_CAST((X), 'GtkTable')).
-define(GTK_NOTEBOOK(X), ?GTK_CAST((X), 'GtkNotebook')).
-define(GTK_PROGRESS(X), ?GTK_CAST((X), 'GtkProgress')).
-define(GTK_PROGRESS_BAR(X), ?GTK_CAST((X), 'GtkProgressBar')).
-define(GTK_RADIO_BUTTON(X), ?GTK_CAST((X), 'GtkRadioButton')).
-define(GTK_PANED(X), ?GTK_CAST((X), 'GtkPaned')).
-define(GTK_CLIST(X), ?GTK_CAST((X), 'GtkCList')).
-define(GTK_BIN(X), ?GTK_CAST((X), 'GtkBin')).
-define(GTK_LABEL(X), ?GTK_CAST((X), 'GtkLabel')).
-define(GTK_SPIN_BUTTON(X), ?GTK_CAST((X), 'GtkSpinButton')).
-define(GTK_MISC(X), ?GTK_CAST((X), 'GtkMisc')).
-define(GTK_ENTRY(X), ?GTK_CAST((X), 'GtkEntry')).
-define(GTK_PACKET(X), ?GTK_CAST((X), 'GtkPacket')).
-define(GTK_FIXED(X), ?GTK_CAST((X), 'GtkFixed')).
-define(GTK_TOOLBAR(X), ?GTK_CAST((X),'GtkToolbar')).
-define(GTK_MENU(X), ?GTK_CAST((X),'GtkMenu')).
-define(GTK_MENU_BAR(X), ?GTK_CAST((X),'GtkMenuBar')).
-define(GTK_MENU_ITEM(X), ?GTK_CAST((X),'GtkMenuItem')).
-define(GTK_LIST(X), ?GTK_CAST((X),'GtkList')).
-define(GTK_DRAWING_AREA(X), ?GTK_CAST((X),'GtkDrawingArea')).

-endif.
